@@ -37,7 +37,10 @@ public:
 
 // Overrides
 public:
+	CActivateManifest *m_manifest;
+
 	virtual BOOL InitInstance();
+	virtual BOOL ExitInstance();
 
 // Implementation
 	afx_msg void OnAppAbout();
