@@ -156,7 +156,7 @@ void CWorkspaceViewerView::Refresh()
 			break;
 		}
 	}
-	CZeroconf zc(eResp, CGlobalSettings::GetLibraryDirectory());
+	CZeroconf zc(eResp, CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDMdns));
 	const CZeroconf::server_struct_t *serv;
 	zc.BrowseForService(SERVICE,CZeroconf::zcAddress);
 	bool first = true;
@@ -190,7 +190,7 @@ void CWorkspaceViewerView::Refresh()
 			if(p) *p='\0';
 			split.m_server = val;
 			if(p) split.m_port = p+1;
-			else split.m_port="2401";
+			else split.m_port="";
 		}
 		else if(!split.Split(val))
 			continue;
