@@ -9,13 +9,15 @@ class CPasswordDialog : public CDialog
 	DECLARE_DYNAMIC(CPasswordDialog)
 
 public:
-	CPasswordDialog(CWnd* pParent = NULL);   // standard constructor
+	CPasswordDialog(bool bTopmost, CWnd* pParent = NULL);   // standard constructor
 	virtual ~CPasswordDialog();
 
 // Dialog Data
 	enum { IDD = IDD_GETPASSWORD };
 
 protected:
+	bool m_bTopmost;
+
 	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
 
 	DECLARE_MESSAGE_MAP()
