@@ -85,6 +85,8 @@ class CAgentApp : public CWinApp
 
 	static DWORD WINAPI _ThreadProc(LPVOID lpParam);
 	DWORD ThreadProc();
+
+	CActivateManifest *m_manifest;
 };
 
 CAgentApp app;
@@ -114,6 +116,9 @@ BOOL CAgentApp::InitInstance()
 	if(pWnd)
 		return FALSE;
 
+	InitCommonControls();
+	m_manifest = new CActivateManifest;
+
 	m_pMainWnd = new CAgentWnd(bU3);
 	m_pMainWnd->CreateEx(0,_T("static"),_T("_CvsAgent"),WS_OVERLAPPED,CRect(1,1,1,1),NULL,0);
 
@@ -148,6 +153,7 @@ BOOL CAgentApp::ExitInstance()
 	nid.hWnd=m_pMainWnd->GetSafeHwnd();
 	nid.uID=IDI_CVSAGENT;
 	Shell_NotifyIcon(NIM_DELETE,&nid);
+	delete m_manifest;
 	return TRUE;
 }
 
