@@ -9,7 +9,9 @@
 
 #define VC_EXTRALEAN		// Exclude rarely-used stuff from Windows headers
 #define STRICT
-#define WINVER 0x0400
+#define WINVER 0x0501
+#define _WIN32_WINNT 0x0501
+#define ISOLATION_AWARE_ENABLED 1
 
 #include <afxwin.h>         // MFC core and standard components
 #include <afxext.h>         // MFC extensions
