@@ -87,25 +87,25 @@ CSqlConnection* CSqlConnection::Alloc(SqlConnectionType type, const char *dir)
 	{
 	case sqtSqlite:
 		CServerIo::trace(3,"Connecting to SQLite");
-		if(!la.Load("sqlite_database"SHARED_LIBRARY_EXTENSION,dir))
+		if(!la.Load("sqlite"SHARED_LIBRARY_EXTENSION,dir))
 			return false;
 		pNewSqlConnection = (CSqlConnection*(*)())la.GetProc("SQLite_Alloc");
 		break;
 	case sqtMysql:
 		CServerIo::trace(3,"Connecting to MySql");
-		if(!la.Load("mysql_database"SHARED_LIBRARY_EXTENSION,dir))
+		if(!la.Load("mysql"SHARED_LIBRARY_EXTENSION,dir))
 			return false;
 		pNewSqlConnection = (CSqlConnection*(*)())la.GetProc("MySql_Alloc");
 		break;
 	case sqtPostgres:
 		CServerIo::trace(3,"Connecting to Postgres");
-		if(!la.Load("postgres_database"SHARED_LIBRARY_EXTENSION,dir))
+		if(!la.Load("postgres"SHARED_LIBRARY_EXTENSION,dir))
 			return false;
 		pNewSqlConnection = (CSqlConnection*(*)())la.GetProc("Postgres_Alloc");
 		break;
 	case sqtOdbc:
 		CServerIo::trace(3,"Connecting to Odbc");
-		if(!la.Load("odbc_database"SHARED_LIBRARY_EXTENSION,dir))
+		if(!la.Load("odbc"SHARED_LIBRARY_EXTENSION,dir))
 			return false;
 		pNewSqlConnection = (CSqlConnection*(*)())la.GetProc("Odbc_Alloc");
 		break;
@@ -113,13 +113,13 @@ CSqlConnection* CSqlConnection::Alloc(SqlConnectionType type, const char *dir)
 		return NULL; // Win32 only (which is normally static)
 	case sqtFirebird:
 		CServerIo::trace(3,"Connecting to Firebird");
-		if(!la.Load("firebird_database"SHARED_LIBRARY_EXTENSION,dir))
+		if(!la.Load("firebird"SHARED_LIBRARY_EXTENSION,dir))
 			return false;
 		pNewSqlConnection = (CSqlConnection*(*)())la.GetProc("Firebird_Alloc");
 		break;
 	case sqtDb2:
 		CServerIo::trace(3,"Connecting to DB2");
-		if(!la.Load("db2_database"SHARED_LIBRARY_EXTENSION,dir))
+		if(!la.Load("db2"SHARED_LIBRARY_EXTENSION,dir))
 			return false;
 		pNewSqlConnection = (CSqlConnection*(*)())la.GetProc("Db2_Alloc");
 		break;
