@@ -92,19 +92,32 @@ which is enough for interrogating the tree.  */
 CXmlNode *CXmlNode::Lookup(const char *path, bool autoCreate /* = false */)
 {
 	ChildArray_t::iterator i,j;
-	const char *p=strchr(path,'/');
+	const char *p;
 	char *q,*r,*s,*tag;
 	static char tmp[256];
 	bool isattr;
+	char qt;
 	int (*cmp)(const char *,const char *);
 
-	if(p && (p-path)<256)
+	for(p=path,qt=0; *p && (qt || *p!='/'); p++)
+	{
+		if(qt && (qt=='\\' || *p==qt))
+			qt=0;
+		else if(*p=='"' || *p=='\'' || *p=='\\')
+			qt=*p;
+	}
+
+	if((p-path)<sizeof(tmp))
 	{
 		memcpy(tmp,path,p-path);
 		tmp[p-path]='\0';
 	}
 	else
-		strcpy(tmp,path);
+	{
+		/* Overflow case.. normally wouldn't happen */
+		strncpy(tmp,path,sizeof(tmp)-1);
+		tmp[sizeof(tmp)-1]='\0';
+	}
 
 	q=strchr(tmp,'[');
 	s=NULL;
@@ -135,7 +148,7 @@ CXmlNode *CXmlNode::Lookup(const char *path, bool autoCreate /* = false */)
 	}
 
 	tag=tmp; isattr=false;
-	if(!p && tag[0]=='@') { tag++; isattr=true; }
+	if(!*p && tag[0]=='@') { tag++; isattr=true; }
 	SortMe();
 	i=std::lower_bound(Children.begin(),Children.end(),std::pair<CXmlNode::XmlTypeEnum,const char *>(isattr?XmlTypeAttribute:XmlTypeNode,tag));
 	if(i!=Children.end() && !strcmp(tag,(*i)->name.c_str()))
@@ -151,7 +164,7 @@ CXmlNode *CXmlNode::Lookup(const char *path, bool autoCreate /* = false */)
 				if(cmp((*j)->GetValue(),r))
 					continue;
 			}
-			if(p)
+			if(*p)
 			{
 				CXmlNode *node = (*i)->Lookup(p+1,autoCreate);
 				if(node)
@@ -172,7 +185,7 @@ CXmlNode *CXmlNode::Lookup(const char *path, bool autoCreate /* = false */)
 		CXmlNode *node = NewNode(tmp,NULL);
 		if(q && r)
 			node->NewAttribute(q,r);
-		if(p)
+		if(*p)
 			return node->Lookup(p+1,autoCreate);
 		else
 			return node;
