@@ -20,10 +20,20 @@
 
 #ifdef _WIN32
 #define WIN32_LEAN_AND_MEAN
+#ifndef WINVER
+	#define WINVER 0x501
+#endif
+#ifndef _WIN32_WINNT
+	#define _WIN32_WINNT 0x501
+#endif
+
 #include <windows.h>
 #include <tchar.h>
 #define SECURITY_WIN32
 #include <security.h>
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#include <wspiapi.h>
 #endif
 
 #ifdef _WIN32
@@ -63,6 +73,7 @@
 
 #ifdef _WIN32
 #include "apiloader/apiloader.h"
+#include "win32/manifest.h"
 #endif
 
 #endif
