@@ -21,7 +21,17 @@
 #include "api_system.h"
 #include "fncmp.h"
 
-CVSAPI_EXPORT int __case_sensitive  = 0;
+static int g_case_sensitive  = 0;
+
+CVSAPI_EXPORT int __case_sensitive()
+{
+	return g_case_sensitive;
+}
+
+CVSAPI_EXPORT void __set_case_sensitive(int cs)
+{
+	g_case_sensitive = cs;
+}
 
 int __cfc(char c, char d, int cs)
 {
