@@ -137,7 +137,7 @@ bool CRunFile::run(const char *path, bool bShow)
 	else
 		m_inFd=-1;
 
-	if(m_outputFn && m_outputFn != StandardOutput)
+	if(m_debugFn || (m_outputFn && m_outputFn != StandardOutput))
 	{
 		_pipe(fd2,0,_O_BINARY | _O_NOINHERIT);
 		m_outFd=fd2[PIPE_READ];
@@ -152,7 +152,7 @@ bool CRunFile::run(const char *path, bool bShow)
 		m_errorData = m_outputData;
 	}
 
-	if(m_errorFn && m_errorFn != StandardError)
+	if(m_debugFn || (m_errorFn && m_errorFn != StandardError))
 	{
 		_pipe(fd3,0,_O_BINARY | _O_NOINHERIT);
 		m_errFd=fd3[PIPE_READ];
@@ -313,24 +313,24 @@ unsigned CRunFile::outputThreadProc()
 	{
 		while(m_errFd>=0 && (size=read(m_errFd,buf,BUFSIZ*10))>0)
 		{
-			m_errorFn(buf,size,m_errorData);
+			if(m_errorFn && m_errorFn != StandardError) m_errorFn(buf,size,m_errorData);
 			if(m_debugFn) m_debugFn(2,buf,size,m_debugData);
 		}
 		while(m_outFd>=0 && (size=read(m_outFd,buf,BUFSIZ*10))>0)
 		{
-			m_outputFn(buf,size,m_outputData);
+			if(m_outputFn && m_outputFn != StandardOutput) m_outputFn(buf,size,m_outputData);
 			if(m_debugFn) m_debugFn(1,buf,size,m_debugData);
 		}
 	} while(WaitForSingleObject(m_hProcess,100)==WAIT_TIMEOUT);
 
 	while(m_errFd>=0 && (size=read(m_errFd,buf,BUFSIZ*10))>0)
 	{
-		m_errorFn(buf,size,m_errorData);
+		if(m_errorFn && m_errorFn != StandardError) m_errorFn(buf,size,m_errorData);
 		if(m_debugFn) m_debugFn(2,buf,size,m_debugData);
 	}
 	while(m_outFd>=0 && (size=read(m_outFd,buf,BUFSIZ*10))>0)
 	{
-		m_outputFn(buf,size,m_outputData);
+		if(m_outputFn && m_outputFn != StandardOutput) m_outputFn(buf,size,m_outputData);
 		if(m_debugFn) m_debugFn(1,buf,size,m_debugData);
 	}
 
