@@ -12,8 +12,9 @@
 
 #define VC_EXTRALEAN		// Exclude rarely-used stuff from Windows headers
 #define STRICT
-#define WINVER 0x0400
-
+#define WINVER 0x0501
+#define WIN32_WINNT 0x0501
+#define ISOLATION_AWARE_ENABLED 1
 #include <afxwin.h>         // MFC core and standard components
 #include <afxext.h>         // MFC extensions
 #include <afxcmn.h>			// MFC support for Windows Common Controls
@@ -42,4 +43,7 @@
 
 int CALLBACK BrowseValid(HWND hWnd, UINT uMsg, LPARAM lParam, LPARAM lpData);
 
+extern bool g_bPrivileged;
+extern HKEY g_hServerKey;
+
 #endif // !defined(AFX_STDAFX_H__F52337E9_30FF_11D2_8EED_00A0C94457BF__INCLUDED_)
