@@ -43,7 +43,6 @@ CAdvancedPage::CAdvancedPage() : CTooltipPropertyPage(CAdvancedPage::IDD)
 {
 	//{{AFX_DATA_INIT(CAdvancedPage)
 	//}}AFX_DATA_INIT
-	m_hServerKey=NULL;
 }
 
 CAdvancedPage::~CAdvancedPage()
@@ -97,12 +96,6 @@ BOOL CAdvancedPage::OnInitDialog()
 
 	CTooltipPropertyPage::OnInitDialog();
 
-	if(!m_hServerKey && RegCreateKeyEx(HKEY_LOCAL_MACHINE,_T("Software\\CVS\\Pserver"),NULL,_T(""),REG_OPTION_NON_VOLATILE,KEY_ALL_ACCESS,NULL,&m_hServerKey,NULL))
-	{
-		fprintf(stderr,"Couldn't create HKLM\\Software\\CVS\\Pserver key, error %d\n",GetLastError());
-		return -1;
-	}
-
 	if(CvsOpenFilter())
 	{
 		m_btCaseSensitive.SetCheck((t=QueryDword(_T("CaseSensitive")))>=0?t:0);
@@ -172,6 +165,22 @@ BOOL CAdvancedPage::OnInitDialog()
 			m_cbZeroconf.SetCurSel(1);
 	}
 
+	if(!g_bPrivileged)
+	{
+		m_btNoReverseDns.EnableWindow(FALSE);
+		m_btAllowTrace.EnableWindow(FALSE);
+		m_btCaseSensitive.EnableWindow(FALSE);
+		m_btLockServerLocal.EnableWindow(FALSE);
+		m_btUnicodeServer.EnableWindow(FALSE);
+		m_btReadOnly.EnableWindow(FALSE);
+		m_btRemoteInit.EnableWindow(FALSE);
+		m_cbZeroconf.EnableWindow(FALSE);
+		m_cbAtomicCheckouts.EnableWindow(FALSE);
+		m_btReplication.EnableWindow(FALSE);
+		m_edReplicationPort.EnableWindow(FALSE);
+		m_stReplicationPort.EnableWindow(FALSE);
+	}
+
 	return TRUE;
 }
 
@@ -181,53 +190,53 @@ BOOL CAdvancedPage::OnApply()
 
 	dwVal=m_btNoReverseDns.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("NoReverseDns"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("NoReverseDns"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_btLockServerLocal.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("LockServerLocal"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("LockServerLocal"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_btAllowTrace.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("AllowTrace"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("AllowTrace"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_btCaseSensitive.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("CaseSensitive"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("CaseSensitive"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_btUnicodeServer.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("UnicodeServer"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("UnicodeServer"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_btReadOnly.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("ReadOnlyServer"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("ReadOnlyServer"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_btRemoteInit.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("RemoteInit"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("RemoteInit"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_cbAtomicCheckouts.GetCheck()?1:0;
 
-	if(RegSetValueEx(m_hServerKey,_T("AtomicCheckouts"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("AtomicCheckouts"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal=m_cbZeroconf.GetCurSel();
 
-	if(RegSetValueEx(m_hServerKey,_T("ResponderType"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("ResponderType"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
-	RegDeleteValue(m_hServerKey,_T("EnableZeroconf"));
+	RegDeleteValue(g_hServerKey,_T("EnableZeroconf"));
 
 	dwVal=m_btReplication.GetCheck();
-	if(RegSetValueEx(m_hServerKey,_T("EnableUnison"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("EnableUnison"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	CString s;
@@ -237,11 +246,11 @@ BOOL CAdvancedPage::OnApply()
 		dwVal=0;
 	if(dwVal)
 	{
-		if(RegSetValueEx(m_hServerKey,_T("UnisonPort"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+		if(RegSetValueEx(g_hServerKey,_T("UnisonPort"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 			AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 	}
 	else
-		RegDeleteValue(m_hServerKey,_T("UnisonPort"));
+		RegDeleteValue(g_hServerKey,_T("UnisonPort"));
 
 	return CTooltipPropertyPage::OnApply();
 }
@@ -251,7 +260,7 @@ DWORD CAdvancedPage::QueryDword(LPCTSTR szKey)
 	BYTE buf[64];
 	DWORD bufLen=sizeof(buf);
 	DWORD dwType;
-	if(RegQueryValueEx(m_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
+	if(RegQueryValueEx(g_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
 		return -1;
 	if(dwType!=REG_DWORD)
 		return -1;
@@ -263,7 +272,7 @@ CString CAdvancedPage::QueryString(LPCTSTR szKey)
 	BYTE buf[16384];
 	DWORD bufLen=sizeof(buf);
 	DWORD dwType;
-	if(RegQueryValueEx(m_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
+	if(RegQueryValueEx(g_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
 		return "";
 	if(dwType!=REG_SZ && dwType!=REG_EXPAND_SZ)
 		return "";
