@@ -139,7 +139,6 @@ CSettingsPage::CSettingsPage() : CTooltipPropertyPage(CSettingsPage::IDD)
 {
 	//{{AFX_DATA_INIT(CSettingsPage)
 	//}}AFX_DATA_INIT
-	m_hServerKey=NULL;
 }
 
 CSettingsPage::~CSettingsPage()
@@ -191,22 +190,16 @@ BOOL CSettingsPage::OnInitDialog()
 
 	CTooltipPropertyPage::OnInitDialog();
 
-	if(!m_hServerKey && RegCreateKeyEx(HKEY_LOCAL_MACHINE,_T("Software\\CVS\\Pserver"),NULL,_T(""),REG_OPTION_NON_VOLATILE,KEY_ALL_ACCESS,NULL,&m_hServerKey,NULL))
-	{
-		fprintf(stderr,"Couldn't create HKLM\\Software\\CVS\\Pserver key, error %d\n",GetLastError());
-		return -1;
-	}
-
 	SetDlgItemInt(IDC_PSERVERPORT,(t=QueryDword(_T("PServerPort")))>=0?t:2401,FALSE);
 	bufLen=sizeof(buf);
-	if(RegQueryValueEx(m_hServerKey,_T("LockServer"),NULL,&dwType,buf,&bufLen))
+	if(RegQueryValueEx(g_hServerKey,_T("LockServer"),NULL,&dwType,buf,&bufLen))
 	{
 		SetDlgItemText(IDC_LOCKSERVER,_T("localhost"));
 		SetDlgItemInt(IDC_LOCKSERVERPORT,(t=QueryDword(_T("LockServerPort")))>=0?t:2402,FALSE);
 	}
 	else
 	{
-		RegDeleteValue(m_hServerKey,_T("LockServerPort"));
+		RegDeleteValue(g_hServerKey,_T("LockServerPort"));
 		TCHAR *p=_tcschr((TCHAR*)buf,':');
 		if(p)
 			*p='\0';
@@ -214,7 +207,7 @@ BOOL CSettingsPage::OnInitDialog()
 		SetDlgItemInt(IDC_LOCKSERVERPORT,p?_tstoi(p+1):2402,FALSE);
 	}
 
-	if(!RegQueryValueEx(m_hServerKey,_T("AnonymousUsername"),NULL,&dwType,buf,&bufLen))
+	if(!RegQueryValueEx(g_hServerKey,_T("AnonymousUsername"),NULL,&dwType,buf,&bufLen))
 		m_edAnonUser.SetWindowText((TCHAR*)buf);
 
 	SendDlgItemMessage(IDC_PSERVERPORT,EM_LIMITTEXT,4);
@@ -224,7 +217,7 @@ BOOL CSettingsPage::OnInitDialog()
 	m_sbLockPort.SetRange32(1,65535);
 
 	bufLen=sizeof(buf);
-	if(RegQueryValueEx(m_hServerKey,_T("TempDir"),NULL,&dwType,buf,&bufLen) &&
+	if(RegQueryValueEx(g_hServerKey,_T("TempDir"),NULL,&dwType,buf,&bufLen) &&
 	   SHRegGetUSValue(_T("SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment"),_T("TEMP"),NULL,(LPVOID)buf,&bufLen,TRUE,NULL,0) &&
 	   !GetEnvironmentVariable(_T("TEMP"),(LPTSTR)buf,sizeof(buf)) &&
 	   !GetEnvironmentVariable(_T("TMP"),(LPTSTR)buf,sizeof(buf)))
@@ -258,9 +251,9 @@ BOOL CSettingsPage::OnInitDialog()
 			/* The server will automatically pick up the domain otherwise */
 			bufLen=sizeof(buf);
 			GetComputerName((LPTSTR)buf,&bufLen);
-			RegSetValueEx(m_hServerKey,_T("DefaultDomain"),0,REG_SZ,(BYTE*)buf,_tcslen((LPCTSTR)buf));
+			RegSetValueEx(g_hServerKey,_T("DefaultDomain"),0,REG_SZ,(BYTE*)buf,_tcslen((LPCTSTR)buf));
 		}
-		RegDeleteValue(m_hServerKey,_T("DontUseDomain"));
+		RegDeleteValue(g_hServerKey,_T("DontUseDomain"));
 		GetParent()->PostMessage(PSM_CHANGED, (WPARAM)m_hWnd); /* SetModified happens too early */
 	}
 
@@ -294,6 +287,22 @@ BOOL CSettingsPage::OnInitDialog()
 	else
 		m_cbRunAsUser.SetCurSel(m_cbRunAsUser.AddString(usr));
 
+	if(!g_bPrivileged)
+	{
+		m_edTempDir.EnableWindow(FALSE);
+		m_edLockServer.EnableWindow(FALSE);
+		m_cbEncryption.EnableWindow(FALSE);
+		m_cbCompression.EnableWindow(FALSE);
+		m_sbServerPort.EnableWindow(FALSE);
+		m_sbLockPort.EnableWindow(FALSE);
+		m_cbDefaultDomain.EnableWindow(FALSE);
+		m_cbRunAsUser.EnableWindow(FALSE);
+		m_edAnonUser.EnableWindow(FALSE);
+		::EnableWindow(*GetDlgItem(IDC_CHANGETEMP),FALSE);
+		::EnableWindow(*GetDlgItem(IDC_LOCKSERVERPORT),FALSE);
+		::EnableWindow(*GetDlgItem(IDC_PSERVERPORT),FALSE);
+	}
+
 	return TRUE;
 }
 
@@ -331,44 +340,44 @@ BOOL CSettingsPage::OnApply()
 	TCHAR fn[MAX_PATH];
 
 	dwVal = GetDlgItemInt(IDC_PSERVERPORT,NULL,FALSE);
-	if(RegSetValueEx(m_hServerKey,_T("PServerPort"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("PServerPort"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	m_edLockServer.GetWindowText(fn,sizeof(fn)-8);
 	dwVal = GetDlgItemInt(IDC_LOCKSERVERPORT,NULL,FALSE);
 	_sntprintf(fn+_tcslen(fn),8,_T(":%d"),dwVal);
-	if(RegSetValueEx(m_hServerKey,_T("LockServer"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
+	if(RegSetValueEx(g_hServerKey,_T("LockServer"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	m_edTempDir.GetWindowText(fn,sizeof(fn));
-	if(RegSetValueEx(m_hServerKey,_T("TempDir"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
+	if(RegSetValueEx(g_hServerKey,_T("TempDir"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal = m_cbCompression.GetItemData(m_cbCompression.GetCurSel());
-	if(RegSetValueEx(m_hServerKey,_T("CompressionLevel"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("CompressionLevel"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	dwVal = m_cbEncryption.GetItemData(m_cbEncryption.GetCurSel());
-	if(RegSetValueEx(m_hServerKey,_T("EncryptionLevel"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
+	if(RegSetValueEx(g_hServerKey,_T("EncryptionLevel"),NULL,REG_DWORD,(BYTE*)&dwVal,sizeof(DWORD)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	m_cbDefaultDomain.GetWindowText(fn,sizeof(fn));
 	if(fn[0]=='(')
-		RegDeleteValue(m_hServerKey,_T("DefaultDomain"));
+		RegDeleteValue(g_hServerKey,_T("DefaultDomain"));
 	else
 	{
-		if(RegSetValueEx(m_hServerKey,_T("DefaultDomain"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
+		if(RegSetValueEx(g_hServerKey,_T("DefaultDomain"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
 			AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 	}
 
 	m_cbRunAsUser.GetWindowText(fn,sizeof(fn));
 	if(fn[0]=='(')
 		fn[0]='\0';
-	if(RegSetValueEx(m_hServerKey,_T("RunAsUser"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
+	if(RegSetValueEx(g_hServerKey,_T("RunAsUser"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	m_edAnonUser.GetWindowText(fn,sizeof(fn));
-	if(RegSetValueEx(m_hServerKey,_T("AnonymousUsername"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
+	if(RegSetValueEx(g_hServerKey,_T("AnonymousUsername"),NULL,REG_SZ,(BYTE*)fn,(_tcslen(fn)+1)*sizeof(TCHAR)))
 		AfxMessageBox(_T("RegSetValueEx failed"),MB_ICONSTOP);
 
 	return CTooltipPropertyPage::OnApply();
@@ -379,7 +388,7 @@ DWORD CSettingsPage::QueryDword(LPCTSTR szKey)
 	BYTE buf[64];
 	DWORD bufLen=sizeof(buf);
 	DWORD dwType;
-	if(RegQueryValueEx(m_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
+	if(RegQueryValueEx(g_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
 		return -1;
 	if(dwType!=REG_DWORD)
 		return -1;
@@ -391,7 +400,7 @@ CString CSettingsPage::QueryString(LPCTSTR szKey)
 	BYTE buf[16384];
 	DWORD bufLen=sizeof(buf);
 	DWORD dwType;
-	if(RegQueryValueEx(m_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
+	if(RegQueryValueEx(g_hServerKey,szKey,NULL,&dwType,buf,&bufLen))
 		return "";
 	if(dwType!=REG_SZ && dwType!=REG_EXPAND_SZ)
 		return "";
