@@ -20,7 +20,8 @@
 #include "stdafx.h"
 #include "ServiceMsg.h"
 #include <config.h>
-#include "../cvsapi/cvsapi.h"
+#include <cvsapi.h>
+#include <cvstools.h>
 #include <malloc.h>
 #include <io.h>
 #include <vector>
@@ -76,6 +77,13 @@ static std::vector<SOCKET> g_Sockets;
 static BOOL g_bStop = FALSE;
 static BOOL g_bTestMode = FALSE;
 
+/* These are from vista SDK */
+#define SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO 6
+typedef struct _SERVICE_REQUIRED_PRIVILEGES_INFO {  
+	LPTSTR pmszRequiredPrivileges;
+} SERVICE_REQUIRED_PRIVILEGES_INFO;
+/*  */
+
 int main(int argc, char* argv[])
 {
     SC_HANDLE  hSCManager = NULL, hService = NULL;
@@ -117,6 +125,12 @@ int main(int argc, char* argv[])
 		TCHAR lsaBuf[10240];
 		DWORD dwLsaBuf;
 
+		if(!CGlobalSettings::isAdmin())
+		{
+			fprintf(stderr,"Must be run as an administrator to use this option\n");
+			return -1;
+		}
+
 		if(RegOpenKeyEx(HKEY_LOCAL_MACHINE,_T("SYSTEM\\CurrentControlSet\\Control\\Lsa"),0,KEY_ALL_ACCESS,&hk))
 		{
 			fprintf(stderr,"Couldn't open LSA registry key, error %d\n",GetLastError());
@@ -160,6 +174,12 @@ int main(int argc, char* argv[])
 		TCHAR lsaBuf[10240];
 		DWORD dwLsaBuf;
 
+		if(!CGlobalSettings::isAdmin())
+		{
+			fprintf(stderr,"Must be run as an administrator to use this option\n");
+			return -1;
+		}
+
 		if(RegOpenKeyEx(HKEY_LOCAL_MACHINE,_T("SYSTEM\\CurrentControlSet\\Control\\Lsa"),0,KEY_ALL_ACCESS,&hk))
 		{
 			fprintf(stderr,"Couldn't open LSA registry key, error %d\n",GetLastError());
@@ -198,19 +218,28 @@ int main(int argc, char* argv[])
 		return 0;
 	}
 
-	if(RegCreateKeyEx(HKEY_LOCAL_MACHINE,_T("Software\\CVS\\Pserver"),NULL,_T(""),REG_OPTION_NON_VOLATILE,KEY_ALL_ACCESS,NULL,&hk,NULL))
-	{ 
-		fprintf(stderr,"Couldn't create HKLM\\Software\\CVS\\Pserver key, error %d\n",GetLastError());
-		return -1;
-	}
-
-    if (!strcmp(argv[1],"-v")) {
+    if (!strcmp(argv[1],"-v"))
+	{
         puts(NTSERVICE_VERSION_STRING);
         return 0;
-        }
+    }
 
 	if(!strcmp(argv[1],"-i"))
 	{
+		HKEY hk;
+
+		if(!CGlobalSettings::isAdmin())
+		{
+			fprintf(stderr,"Must be run as an administrator to use this option\n");
+			return -1;
+		}
+
+		if(RegCreateKeyEx(HKEY_LOCAL_MACHINE,_T("Software\\CVS\\Pserver"),NULL,_T(""),REG_OPTION_NON_VOLATILE,KEY_ALL_ACCESS,NULL,&hk,NULL))
+		{ 
+			fprintf(stderr,"Couldn't create HKLM\\Software\\CVS\\Pserver key, error %d\n",GetLastError());
+			return -1;
+		}
+
 		if(argc==3)
 		{
 			szRoot = argv[2];
@@ -254,18 +283,29 @@ int main(int argc, char* argv[])
 				{
 					0;
 				}
+				SERVICE_REQUIRED_PRIVILEGES_INFO sp = { SE_NETWORK_LOGON_NAME"\0"SE_IMPERSONATE_NAME"\0" };
+				if(!pChangeServiceConfig2(hService,SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO,&sp))
+				{
+					0;
+				}
 			}
 		}
 		CloseServiceHandle(hService);
 		CloseServiceHandle(hSCManager);
 		ReportError(FALSE,DISPLAY_NAMEA " installed successfully");
 		printf(DISPLAY_NAMEA " installed successfully\n");
+		RegCloseKey(hk);
 	}
 	
-	RegCloseKey(hk);
 
 	if(!strcmp(argv[1],"-u"))
 	{
+		if(!CGlobalSettings::isAdmin())
+		{
+			fprintf(stderr,"Must be run as an administrator to use this option\n");
+			return -1;
+		}
+
 		// connect to  the service control manager
 		if((hSCManager = OpenSCManager(NULL, NULL, SC_MANAGER_CREATE_SERVICE)) == NULL)
 		{
@@ -290,6 +330,9 @@ int main(int argc, char* argv[])
 	}	
 	else if(!strcmp(argv[1],"-test"))
 	{
+		if(!CGlobalSettings::isAdmin())
+			fprintf(stderr,"**WARNING** Not running as administrator.  Some functions may fail.\n");
+
 		ServiceMain(999,NULL);
 	}
 	return 0;
