@@ -79,6 +79,7 @@ namespace
 	}
 	const char *server_enumerate_protocols(const server_interface *server, int *context, enum proto_type type)
 	{
+		CServerIo::trace(3,"server_enumerate_protocols(%d,%d)",context?*context:0,(int)type);
 		do
 		{
 			const char *proto = m_lib.EnumerateProtocols(context);
@@ -91,6 +92,7 @@ namespace
 				{
 					if((!protocol->auth_protocol_connect || !protocol->connect))
 					{
+						CServerIo::trace(3,"%s has no server component",proto);
 						m_lib.UnloadProtocol(protocol);
 						continue;
 					}
@@ -99,10 +101,13 @@ namespace
 						char value[64];
 						int val = 1;
 
+						CServerIo::trace(3,"Checking key %s",protocol->plugin.key);
+
 						if(!CGlobalSettings::GetGlobalValue("cvsnt","Plugins",protocol->plugin.key,value,sizeof(value)))
 							val = atoi(value);
 						if(!val)
 						{
+							CServerIo::trace(3,"%s is disabled",proto);
 							m_lib.UnloadProtocol(protocol);
 							continue;
 						}
@@ -110,11 +115,13 @@ namespace
 				}
 				if(type == ptClient && !protocol->connect)
 				{
+					CServerIo::trace(3,"$s has no client component",proto);
 					m_lib.UnloadProtocol(protocol);
 					continue;
 				}
 				m_lib.UnloadProtocol(protocol);
 			}
+			CServerIo::trace(3,"Returning protocol :%s:",proto);
 			return proto;
 		} while(1);
 	}
@@ -138,7 +145,7 @@ namespace
 
 bool CProtocolLibrary::SetupServerInterface(cvsroot *root, int io_socket /* = 0 */)
 {
-	cvs_interface.library_dir = CGlobalSettings::GetLibraryDirectory();
+	cvs_interface.library_dir = CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDLib);
 	cvs_interface.config_dir = CGlobalSettings::GetConfigDirectory();
 	cvs_interface.cvs_command = CGlobalSettings::GetCvsCommand();
 	cvs_interface.current_root = root;
@@ -175,15 +182,15 @@ const protocol_interface *CProtocolLibrary::LoadProtocol(const char *protocol)
 		
 #ifdef _WIN32
 	char buf[128];
-	cvs::sprintf(fn,128,"%s/protocol_map.ini",CGlobalSettings::GetLibraryDirectory());
+	cvs::sprintf(fn,128,"%s/protocol_map.ini",CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDProtocols));
 	if(GetPrivateProfileStringA("cvsnt",protocol,NULL,buf,sizeof(buf),fn.c_str()))
 		fn = buf;
 	else
 #endif
-		cvs::sprintf(fn,128,"%s_protocol"SHARED_LIBRARY_EXTENSION,protocol);
+		cvs::sprintf(fn,128,"%s"SHARED_LIBRARY_EXTENSION,protocol);
 
 	CServerIo::trace(3,"Loading protocol %s as %s",protocol,fn.c_str());
-	if(!lib.Load(fn.c_str(),CGlobalSettings::GetLibraryDirectory()))
+	if(!lib.Load(fn.c_str(),CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDProtocols)))
 	{
 		CServerIo::trace(3,"Error loading %s",fn.c_str());
 		return NULL; // Couldn't find protocol - not supported, or supporting DLLs missing
@@ -275,30 +282,31 @@ const protocol_interface *CProtocolLibrary::FindProtocol(const char *tagline, bo
 		protocol=LoadProtocol(proto);
 		if(!protocol)
 			continue;
-		if(secure && !protocol->wrap)
+		CServerIo::trace(3,"Checking protocol %s",proto);
+		if(secure && !protocol->wrap && !(protocol->valid_elements&flagAlwaysEncrypted))
 		{
-			CServerIo::trace(3,"%s protocol disabled due to security settings.",proto);
+			CServerIo::trace(3,"%s protocol disabled as it does not support encryption.",proto);
 			UnloadProtocol(protocol);
 			continue;
 		}
 		if(protocol->auth_protocol_connect)
 		{
-/*
-			if(protocol->ui && protocol->ui->key)
+			if(protocol->plugin.key)
 			{
 				char value[64];
 				int val = 1;
 
-				if(!CGlobalSettings::GetGlobalValue("cvsnt","Plugins",protocol->ui->key,value,sizeof(value)))
+				CServerIo::trace(3,"Checking key %s",protocol->plugin.key);
+
+				if(!CGlobalSettings::GetGlobalValue("cvsnt","Plugins",protocol->plugin.key,value,sizeof(value)))
 					val = atoi(value);
 				if(!val)
 				{
-					CServerIo::trace(3,"%s protocol not enabled.",proto);
+					CServerIo::trace(3,"%s is disabled",proto);
 					UnloadProtocol(protocol);
 					continue;
 				}
 			}
-*/
 			SetupServerInterface(NULL,io_socket);
 			if(temp_protocol)
 				*temp_protocol = protocol;
@@ -333,9 +341,9 @@ const char *CProtocolLibrary::EnumerateProtocols(int *context)
 {
 	if(!*context)
 	{
-		CServerIo::trace(3,"EnumerateProtocols: %s",CGlobalSettings::GetLibraryDirectory());
+		CServerIo::trace(3,"EnumerateProtocols: %s",CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDProtocols));
 		m_acc.close();
-		if(!m_acc.open(CGlobalSettings::GetLibraryDirectory(),"*_protocol"SHARED_LIBRARY_EXTENSION))
+		if(!m_acc.open(CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDProtocols),"*"SHARED_LIBRARY_EXTENSION))
 		{
 			CServerIo::trace(3,"EnumeratePrototocols failed");
 			return NULL;
@@ -350,7 +358,7 @@ const char *CProtocolLibrary::EnumerateProtocols(int *context)
 		return NULL;
 	}
 
-	m_inf.filename.resize(m_inf.filename.find_last_of('_'));
+	m_inf.filename.resize(m_inf.filename.find_last_of('.'));
 	return m_inf.filename.c_str();
 }
 
