@@ -63,22 +63,22 @@ bool CServerConnection::Connect(const char *command, ServerConnectionInfo *info,
 		{
 		case 0: // Default, no password
 			if(info->username.size())
-				cvs::sprintf(info->root,80,":%s%s:%s%s%s@%s:%s:%s",info->protocol.c_str(),keys.c_str(),info->username.c_str(),info->password.size()?":":"",info->password.c_str(),info->server.c_str(),info->port.c_str(),info->directory.c_str());
+				cvs::sprintf(info->root,80,":%s%s:%s%s%s@%s%s%s:%s",info->protocol.c_str(),keys.c_str(),info->username.c_str(),info->password.size()?":":"",info->password.c_str(),info->server.c_str(),info->port.size()?":":"",info->port.c_str(),info->directory.c_str());
 			else
-				cvs::sprintf(info->root,80,":%s%s:%s:%s:%s",info->protocol.c_str(),keys.c_str(),info->server.c_str(),info->port.c_str(),info->directory.c_str());
+				cvs::sprintf(info->root,80,":%s%s:%s%s%s:%s",info->protocol.c_str(),keys.c_str(),info->server.c_str(),info->port.size()?":":"",info->port.c_str(),info->directory.c_str());
 			pass++;
 			break;
 		case 1: // Default, password (loop until cancel)
-			cvs::sprintf(info->root,80,":%s%s:%s:%s:%s",info->protocol.c_str(),keys.c_str(),info->server.c_str(),info->port.c_str(),info->directory.c_str());
+			cvs::sprintf(info->root,80,":%s%s:%s%s%s:%s",info->protocol.c_str(),keys.c_str(),info->server.c_str(),info->port.size()?":":"",info->port.c_str(),info->directory.c_str());
 			if(!callback->AskForPassword(info))
 			{
 				info->invalid=true;
 				return false;
 			}
 			if(info->username.size())
-				cvs::sprintf(info->root,80,":%s%s:%s%s%s@%s:%s:%s",info->protocol.c_str(),keys.c_str(),info->username.c_str(),info->password.size()?":":"",info->password.c_str(),info->server.c_str(),info->port.c_str(),info->directory.c_str());
+				cvs::sprintf(info->root,80,":%s%s:%s%s%s@%s%s%s:%s",info->protocol.c_str(),keys.c_str(),info->username.c_str(),info->password.size()?":":"",info->password.c_str(),info->server.c_str(),info->port.size()?":":"",info->port.c_str(),info->directory.c_str());
 			else
-				cvs::sprintf(info->root,80,":%s%s:%s:%s:%s",info->protocol.c_str(),keys.c_str(),info->server.c_str(),info->port.c_str(),info->directory.c_str());
+				cvs::sprintf(info->root,80,":%s%s:%s%s%s:%s",info->protocol.c_str(),keys.c_str(),info->server.c_str(),info->port.size()?":":"",info->port.c_str(),info->directory.c_str());
 			break;
 		}
 
@@ -166,7 +166,8 @@ int CServerConnection::ServerOutput(const char *data,size_t len)
 		{
 			q--;
 			str.assign(p,q-p);
-			if(strstr(str.c_str(),"Connection to server failed") || strstr(str.c_str(),"is not installed on this system"))
+			CServerIo::trace(3,"Connection trace: %s\n",str.c_str());
+			if(strstr(str.c_str(),"Connection to server failed") || strstr(str.c_str(),"is not installed on this system") || strstr(str.c_str(),"is not available on this system"))
 			{
 				m_error = 1;
 				return -1;
