@@ -30,6 +30,8 @@
 #include "plugin_interface.h"
 
 #ifdef _WIN32
+#include "../../version.h"
+
 #include <comdef.h>
 #include <objbase.h>
 
@@ -369,7 +371,7 @@ const trigger_interface *CTriggerLibrary::LoadTrigger(const char *library, const
 		}
 		if(FAILED(i4->QueryInterface(IID_ICvsInfo5,(void**)&i5)))
 			i5 = NULL;
-		if(FAILED(i6->QueryInterface(IID_ICvsInfo6,(void**)&i6)))
+		if(FAILED(i4->QueryInterface(IID_ICvsInfo6,(void**)&i6)))
 			i6 = NULL;
 
 		trigger_info_t *inf = new trigger_info_t;
@@ -379,6 +381,13 @@ const trigger_interface *CTriggerLibrary::LoadTrigger(const char *library, const
 		inf->is.i5 = i5;
 		inf->is.i6 = i6;
 		cb->plugin.__cvsnt_reserved = inf;
+		cb->plugin.interface_version=PLUGIN_INTERFACE_VERSION;
+		cb->plugin.description="COM Interface";
+		cb->plugin.version=CVSNT_PRODUCTVERSION_STRING;
+		cb->plugin.init=NULL;
+		cb->plugin.destroy=NULL;
+		cb->plugin.get_interface=NULL;
+		cb->plugin.configure=NULL;
 		cb->init=COM_init;
 		cb->close=COM_close;
 		cb->history=COM_history;
@@ -401,8 +410,9 @@ const trigger_interface *CTriggerLibrary::LoadTrigger(const char *library, const
 #endif
 	{
 		CLibraryAccess lib;
+		cvs::filename fn;
 
-		if(!lib.Load(library,CGlobalSettings::GetLibraryDirectory()))
+		if(!lib.Load(library,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDTriggers)))
 		{
 #ifdef _WIN32
 			DWORD dwErr = GetLastError();
