@@ -18,10 +18,14 @@
 #ifndef CVSTOOLS__EXPORT__H
 #define CVSTOOLS__EXPORT__H
 
-#if defined (_WIN32) && !defined(CVSTOOLS_EXPORT)
-	#define CVSTOOLS_EXPORT __declspec(dllimport)
-#elif !defined(_WIN32)
-#define CVSTOOLS_EXPORT
+#ifdef _WIN32
+ #ifndef CVSTOOLS_EXPORT
+  #define CVSTOOLS_EXPORT __declspec(dllimport)
+ #endif
+#elif defined(_CVSTOOLS) && defined(HAVE_GCC_VISIBILITY)
+ #define CVSTOOLS_EXPORT __attribute__ ((visibility("default")))
+#else
+ #define CVSTOOLS_EXPORT
 #endif
 
 #endif
