@@ -30,11 +30,11 @@
 namespace
 {
 	const char *_cvs_config_dir_default = CVS_CONFIG_DIR;
-	const char *cvs_config_dir = _cvs_config_dir_default;
+	const char *cvs_config_dir = NULL;
 	const char *_cvs_library_dir_default = CVS_LIBRARY_DIR;
-	const char *cvs_library_dir = _cvs_library_dir_default;
+	const char *cvs_library_dir = NULL;
 	const char *_cvs_program_name_default = "cvsnt";
-	const char *cvs_program_name = _cvs_program_name_default;
+	const char *cvs_program_name = NULL;
 
 	int GetCachedPassword(const char *key, char *buffer, int buffer_len)
 	{
@@ -47,17 +47,17 @@ namespace
 			return -1;
 		if(sock.send(key,(int)strlen(key))<=0)
 		{
-			CServerIo::CServerIo::trace(1,"Error sending to password agent");
+			CServerIo::trace(1,"Error sending to password agent");
 			return -1;
 		}
 		if(sock.recv(buffer,buffer_len)<=0)
 		{
-			CServerIo::CServerIo::trace(1,"Error receiving from password agent");
+			CServerIo::trace(1,"Error receiving from password agent");
 			return -1;
 		}
 		if(buffer[0]==-1) /* No passwd */
 		{
-			CServerIo::CServerIo::trace(2,"No password stored in passwd agent");
+			CServerIo::trace(2,"No password stored in passwd agent");
 			return -1;
 		}
 		sock.close();
@@ -86,13 +86,13 @@ namespace
   		mkdir(fn.c_str(),0777);
 		cvs::sprintf(fn,80,"%s/.cvs/%s",pw->pw_dir?pw->pw_dir:"",key?key:"config");
 
-  		CServerIo::CServerIo::trace(2,"Config file name %s",fn.c_str());
+  		CServerIo::trace(2,"Config file name %s",fn.c_str());
 	}
 	void GetGlobalConfigFile(const char *product, const char *key, cvs::filename& fn)
 	{
 		if(product && strcmp(product,"cvsnt"))
 			CServerIo::error("Global setting for product '%s' not supported",product);
-		cvs::sprintf(fn,80,"%s/%s",cvs_config_dir,key?key:"config");
+		cvs::sprintf(fn,80,"%s/%s",cvs_config_dir?cvs_config_dir:_cvs_config_dir_default,key?key:"config");
 	}
 };
 
@@ -134,7 +134,7 @@ int CGlobalSettings::_GetUserValue(const char *product, const char *key, const c
     f=fopen(fn.c_str(),"r");
     if(f==NULL)
 	{
-	   CServerIo::CServerIo::trace(3,"Could not open %s",fn.c_str());
+	   CServerIo::trace(3,"Could not open %s",fn.c_str());
        return -1;
 	}
 
@@ -173,7 +173,7 @@ int CGlobalSettings::_SetUserValue(const char *product, const char *key, const c
 	char *p;
 	bool found;
 
-    CServerIo::CServerIo::trace(3,"SetUserValue(%s,%s)",key,value?value:"");
+    CServerIo::trace(3,"SetUserValue(%s,%s)",key,value?value:"");
 
 	GetUserConfigFile(product,key,fn);
 	f=fopen(fn.c_str(),"r");
@@ -182,7 +182,7 @@ int CGlobalSettings::_SetUserValue(const char *product, const char *key, const c
 		f=fopen(fn.c_str(),"w");
         if(f==NULL)
 	    {
-	      	CServerIo::CServerIo::trace(1,"Couldn't create config file %s",fn.c_str());
+	      	CServerIo::trace(1,"Couldn't create config file %s",fn.c_str());
 	        return -1;
 										                }
             if(buffer)
@@ -494,40 +494,102 @@ int CGlobalSettings::DeleteGlobalKey(const char *product, const char *key)
 
 const char *CGlobalSettings::GetConfigDirectory()
 {
-	return cvs_config_dir;
+	return cvs_config_dir?cvs_config_dir:_cvs_config_dir_default;
 }
 
-const char *CGlobalSettings::GetLibraryDirectory()
+const char *CGlobalSettings::GetLibraryDirectory(GLDType type)
 {
-	return cvs_library_dir;
+	const char *cvsDir = cvs_library_dir?cvs_library_dir:_cvs_library_dir_default;
+	/* At some point replace this with something more complex.  For now
+	   it serves the purpose */
+	static const char *cvsDirProtocols = NULL;
+	static const char *cvsDirTriggers = NULL;
+	static const char *cvsDirXdiff = NULL;
+	static const char *cvsDirMdns = NULL;
+	static const char *cvsDirDatabase = NULL;
+	switch(type)
+	{
+		case GLDLib:
+			return cvsDir;
+		case GLDProtocols:
+			if(!cvsDirProtocols)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/protocols";
+				cvsDirProtocols = strdup(cv.c_str());
+			}
+			return cvsDirProtocols;
+		case GLDTriggers:
+			if(!cvsDirTriggers)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/triggers";
+				cvsDirTriggers = strdup(cv.c_str());
+			}
+			return cvsDirTriggers;
+		case GLDXdiff:
+			if(!cvsDirXdiff)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/xdiff";
+				cvsDirXdiff = strdup(cv.c_str());
+			}
+			return cvsDirXdiff;
+		case GLDMdns:
+			if(!cvsDirMdns)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/mdns";
+				cvsDirMdns = strdup(cv.c_str());
+			}
+			return cvsDirMdns;
+		case GLDDatabase:
+			if(!cvsDirDatabase)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/database";
+				cvsDirDatabase = strdup(cv.c_str());
+			}
+			return cvsDirDatabase;
+		default:
+			return cvsDir;
+	}
 }
 
 bool CGlobalSettings::SetConfigDirectory(const char *directory)
 {
-	if(cvs_config_dir!=_cvs_config_dir_default)
+	CServerIo::trace(1,"Config directory changed to %s",directory?directory:_cvs_config_dir_default);
+	if(cvs_config_dir && cvs_config_dir!=_cvs_config_dir_default)
     	free((void*)cvs_config_dir);
-    cvs_config_dir=strdup(directory);
+    cvs_config_dir=directory?strdup(directory):NULL;
     return true;
 }
 
 bool CGlobalSettings::SetLibraryDirectory(const char *directory)
 {
-	if(cvs_library_dir!=_cvs_library_dir_default)
+	CServerIo::trace(1,"Library directory changed to %s",directory?directory:_cvs_library_dir_default);
+	if(cvs_library_dir && cvs_library_dir!=_cvs_library_dir_default)
     	free((void*)cvs_library_dir);
-	cvs_library_dir=strdup(directory);
+	cvs_library_dir=directory?strdup(directory):NULL;
 	return true;
 }
 
 const char *CGlobalSettings::GetCvsCommand()
 {
-	return cvs_program_name;
+	return cvs_program_name?cvs_program_name:_cvs_program_name_default;
 }
 
 bool CGlobalSettings::SetCvsCommand(const char *directory)
 {
-	if(cvs_program_name!=_cvs_program_name_default)
+	CServerIo::trace(1,"CVS program name set to %s",directory?directory:_cvs_program_name_default);
+	if(cvs_program_name && cvs_program_name!=_cvs_program_name_default)
     	free((void*)cvs_program_name);
-	cvs_program_name=strdup(directory);
+	cvs_program_name=directory?strdup(directory):NULL;
 	return true;
 }
 
