@@ -575,7 +575,7 @@ void CBrowserDialog::PopulateLocal(HWND hTree, bool bStatic)
 			break;
 		}
 	}
-	CZeroconf zc(eResp, CGlobalSettings::GetLibraryDirectory());
+	CZeroconf zc(eResp, CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDMdns));
 	const CZeroconf::server_struct_t *serv;
 	zc.BrowseForService("_cvspserver._tcp",CZeroconf::zcAddress);
 	bool first = true;
@@ -610,7 +610,7 @@ void CBrowserDialog::PopulateLocal(HWND hTree, bool bStatic)
 				if(p) *p='\0';
 				split.m_server = val;
 				if(p) split.m_port = p+1;
-				else split.m_port="2401";
+				else split.m_port="";
 			}
 			else if(!split.Split(val))
 				continue;
@@ -918,10 +918,15 @@ INT_PTR CBrowserPasswordDialog::dlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPA
 				}
 				else
 				{
+					GetDlgItemText(hWnd,IDC_PASSWORD,tmp,sizeof(tmp));
+					if(_tcschr(tmp,'@') || _tcschr(tmp,':') || _tcschr(tmp,'"'))
+					{
+						MessageBox(hWnd,_T("Password contains invalid characters."),_T("Password Required"),MB_ICONSTOP|MB_OK);
+						return 0;
+					}
+					m_activedir->password = cvs::narrow(tmp);
 					GetDlgItemText(hWnd,IDC_USERNAME,tmp,sizeof(tmp));
 					m_activedir->username = cvs::narrow(tmp);
-					GetDlgItemText(hWnd,IDC_PASSWORD,tmp,sizeof(tmp));
-					m_activedir->password = cvs::narrow(tmp);
 					GetDlgItemText(hWnd,IDC_KEYWORDS,tmp,sizeof(tmp));
 					m_activedir->keywords = cvs::narrow(tmp);
 					GetDlgItemText(hWnd,IDC_PROTOCOL,tmp,sizeof(tmp));
@@ -1163,8 +1168,16 @@ INT_PTR CBrowserRootDialog::dlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM
 			{
 				EnableWindow(GetDlgItem(hWnd,IDC_KEYWORDS),TRUE);
 				EnableWindow(GetDlgItem(hWnd,IDC_KEYWORDS_TEXT),TRUE);
-				EnableWindow(GetDlgItem(hWnd,IDC_PORT),TRUE);
-				EnableWindow(GetDlgItem(hWnd,IDC_PORT_TEXT),TRUE);
+				if(!strcmp(m_activedir->protocol.c_str(),"ext"))
+				{
+					EnableWindow(GetDlgItem(hWnd,IDC_PORT),FALSE);
+					EnableWindow(GetDlgItem(hWnd,IDC_PORT_TEXT),FALSE);
+				}
+				else
+				{
+					EnableWindow(GetDlgItem(hWnd,IDC_PORT),TRUE);
+					EnableWindow(GetDlgItem(hWnd,IDC_PORT_TEXT),TRUE);
+				}
 				EnableWindow(GetDlgItem(hWnd,IDC_MODULE),m_flags&BRDShowModule?TRUE:FALSE);
 				EnableWindow(GetDlgItem(hWnd,IDC_MODULE_TEXT),m_flags&BRDShowModule?TRUE:FALSE);
 				SetDlgItemText(hWnd,IDC_DIRECTORY_TEXT,_T("Repository"));
@@ -1178,10 +1191,13 @@ INT_PTR CBrowserRootDialog::dlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM
 				m_activedir->srvname = cvs::narrow(tmp);
 				GetDlgItemText(hWnd,IDC_SERVER,tmp,sizeof(tmp));
 				m_activedir->server = cvs::narrow(tmp);
-				GetDlgItemText(hWnd,IDC_PORT,tmp,sizeof(tmp));
-				m_activedir->port = cvs::narrow(tmp);
-				if(!m_activedir->port.size())
-					m_activedir->port="2401";
+				if(strcmp(m_activedir->protocol.c_str(),"ext"))
+				{
+					GetDlgItemText(hWnd,IDC_PORT,tmp,sizeof(tmp));
+					m_activedir->port = cvs::narrow(tmp);
+				}
+				else
+					m_activedir->port="";
 				if(m_bCollapsed)
 				{
 					CRootSplitter split;
@@ -1231,12 +1247,17 @@ INT_PTR CBrowserRootDialog::dlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM
 				}
 				else
 				{
+					GetDlgItemText(hWnd,IDC_PASSWORD,tmp,sizeof(tmp));
+					if(_tcschr(tmp,'@') || _tcschr(tmp,':') || _tcschr(tmp,'"'))
+					{
+						MessageBox(hWnd,_T("Password contains invalid characters."),cvs::wide(m_szTitle.c_str()),MB_ICONSTOP|MB_OK);
+						return 0;
+					}
+					m_activedir->password = cvs::narrow(tmp);
 					GetDlgItemText(hWnd,IDC_PROTOCOL,tmp,sizeof(tmp));
 					m_activedir->protocol = cvs::narrow(tmp);
 					GetDlgItemText(hWnd,IDC_USERNAME,tmp,sizeof(tmp));
 					m_activedir->username = cvs::narrow(tmp);
-					GetDlgItemText(hWnd,IDC_PASSWORD,tmp,sizeof(tmp));
-					m_activedir->password = cvs::narrow(tmp);
 					GetDlgItemText(hWnd,IDC_DIRECTORY,tmp,sizeof(tmp));
 					if(tmp[0]!='/')
 						m_activedir->directory="/";
@@ -1308,8 +1329,16 @@ INT_PTR CBrowserRootDialog::dlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM
 							EnableWindow(GetDlgItem(hWnd,IDC_MODULE_TEXT),m_flags&BRDShowModule?TRUE:FALSE);
 							EnableWindow(GetDlgItem(hWnd,IDC_KEYWORDS),TRUE);
 							EnableWindow(GetDlgItem(hWnd,IDC_KEYWORDS_TEXT),TRUE);
-							EnableWindow(GetDlgItem(hWnd,IDC_PORT),TRUE);
-							EnableWindow(GetDlgItem(hWnd,IDC_PORT_TEXT),TRUE);
+							if(!_tcscmp(tmp,_T("ext")))
+							{
+								EnableWindow(GetDlgItem(hWnd,IDC_PORT),FALSE);
+								EnableWindow(GetDlgItem(hWnd,IDC_PORT_TEXT),FALSE);
+							}
+							else
+							{
+								EnableWindow(GetDlgItem(hWnd,IDC_PORT),TRUE);
+								EnableWindow(GetDlgItem(hWnd,IDC_PORT_TEXT),TRUE);
+							}
 							SetDlgItemText(hWnd,IDC_DIRECTORY_TEXT,_T("Repository"));
 						}
 						return TRUE;
