@@ -19,6 +19,8 @@
 #include <cvsapi.h>
 #include "../GlobalSettings.h"
 
+#include <lm.h>
+
 namespace
 {
 	static char cvs_config_dir[_MAX_PATH] = {0};
@@ -30,11 +32,9 @@ namespace
 		if(!*dir) /* Only do this once */
 		{
 			if(CGlobalSettings::GetGlobalValue("cvsnt","PServer","LibraryPath",dir,size) &&
-			   CGlobalSettings::GetUserValue("cvsnt","PServer","LibraryPath",dir,size) &&
-			   CGlobalSettings::GetGlobalValue("cvsnt","PServer","InstallPath",dir,size) &&
-			   CGlobalSettings::GetUserValue("cvsnt","PServer","InstallPath",dir,size))
+			   CGlobalSettings::GetUserValue("cvsnt","PServer","LibraryPath",dir,size))
 			{
-				if (GetModuleFileNameA(NULL, dir, size))
+				if (GetModuleFileNameA(GetModuleHandleA("cvstools.dll"), dir, size))
 				{
 					char *p;
 
@@ -160,16 +160,12 @@ int CGlobalSettings::_GetUserValue(const char *product, const char *key, const c
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ,&hKey) &&
-	   RegCreateKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,NULL,0,KEY_READ,NULL,&hKey,NULL))
-	{
+	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ,&hKey))
 		return -1; // Couldn't open or create key
-	}
 
 	if(key)
 	{
-		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey) &&
-		   RegCreateKeyExA(hKey,key,0,NULL,0,KEY_READ,NULL,&hSubKey,NULL))
+		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey))
 		{
 			RegCloseKey(hKey);
 			return -1; // Couldn't open or create key
@@ -299,16 +295,14 @@ int CGlobalSettings::EnumUserValues(const char *product, const char *key, int va
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ,&hKey) &&
-	   RegCreateKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,NULL,0,KEY_READ,NULL,&hKey,NULL))
+	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ,&hKey))
 	{
 		return -1; // Couldn't open or create key
 	}
 
 	if(key)
 	{
-		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey) &&
-		   RegCreateKeyExA(hKey,key,0,NULL,0,KEY_READ,NULL,&hSubKey,NULL))
+		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey))
 		{
 			RegCloseKey(hKey);
 			return -1; // Couldn't open or create key
@@ -343,16 +337,14 @@ int CGlobalSettings::EnumUserKeys(const char *product, const char *key, int valu
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ,&hKey) &&
-	   RegCreateKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,NULL,0,KEY_READ,NULL,&hKey,NULL))
+	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ,&hKey))
 	{
 		return -1; // Couldn't open or create key
 	}
 
 	if(key)
 	{
-		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey) &&
-		   RegCreateKeyExA(hKey,key,0,NULL,0,KEY_READ,NULL,&hSubKey,NULL))
+		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey))
 		{
 			RegCloseKey(hKey);
 			return -1; // Couldn't open or create key
@@ -382,11 +374,8 @@ int CGlobalSettings::DeleteUserKey(const char *product, const char *key)
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ|KEY_WRITE,&hKey) &&
-	   RegCreateKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,NULL,0,KEY_READ|KEY_WRITE,NULL,&hKey,NULL))
-	{
+	if(RegOpenKeyExA(HKEY_CURRENT_USER,regkey.c_str(),0,KEY_READ|KEY_WRITE,&hKey))
 		return -1; // Couldn't open or create key
-	}
 
 	RegDeleteKeyA(hKey,key);
 
@@ -425,16 +414,14 @@ int CGlobalSettings::GetGlobalValue(const char *product, const char *key, const
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ,&hKey) &&
-	   RegCreateKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,NULL,0,KEY_READ,NULL,&hKey,NULL))
+	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ,&hKey))
 	{
 		return -1; // Couldn't open or create key
 	}
 
 	if(key)
 	{
-		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey) &&
-		   RegCreateKeyExA(hKey,key,0,NULL,0,KEY_READ,NULL,&hSubKey,NULL))
+		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey))
 		{
 			RegCloseKey(hKey);
 			return -1; // Couldn't open or create key
@@ -463,6 +450,9 @@ int CGlobalSettings::SetGlobalValue(const char *product, const char *key, const
 	DWORD dwLen;
 	cvs::string regkey;
 
+	if(!isAdmin())
+		return -1;
+
 	if(!product || !strcmp(product,"cvsnt"))
 		regkey="Software\\CVS";
 	else
@@ -510,6 +500,9 @@ int CGlobalSettings::SetGlobalValue(const char *product, const char *key, const
 	DWORD dwLen;
 	cvs::string regkey;
 
+	if(!isAdmin())
+		return -1;
+
 	if(!product || !strcmp(product,"cvsnt"))
 		regkey="Software\\CVS";
 	else
@@ -560,16 +553,14 @@ int CGlobalSettings::EnumGlobalValues(const char *product, const char *key, int
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ,&hKey) &&
-	   RegCreateKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,NULL,0,KEY_READ,NULL,&hKey,NULL))
+	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ,&hKey))
 	{
 		return -1; // Couldn't open or create key
 	}
 
 	if(key)
 	{
-		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey) &&
-		   RegCreateKeyExA(hKey,key,0,NULL,0,KEY_READ,NULL,&hSubKey,NULL))
+		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey))
 		{
 			RegCloseKey(hKey);
 			return -1; // Couldn't open or create key
@@ -604,16 +595,14 @@ int CGlobalSettings::EnumGlobalKeys(const char *product, const char *key, int va
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ,&hKey) &&
-	   RegCreateKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,NULL,0,KEY_READ,NULL,&hKey,NULL))
+	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ,&hKey))
 	{
 		return -1; // Couldn't open or create key
 	}
 
 	if(key)
 	{
-		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey) &&
-		   RegCreateKeyExA(hKey,key,0,NULL,0,KEY_READ,NULL,&hSubKey,NULL))
+		if(RegOpenKeyExA(hKey,key,0,KEY_READ,&hSubKey))
 		{
 			RegCloseKey(hKey);
 			return -1; // Couldn't open or create key
@@ -643,8 +632,7 @@ int CGlobalSettings::DeleteGlobalKey(const char *product, const char *key)
 	else
 		cvs::sprintf(regkey,64,"Software\\March Hare Software Ltd\\%s",product);
 
-	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ|KEY_WRITE,&hKey) &&
-	   RegCreateKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,NULL,0,KEY_READ|KEY_WRITE,NULL,&hKey,NULL))
+	if(RegOpenKeyExA(HKEY_LOCAL_MACHINE,regkey.c_str(),0,KEY_READ|KEY_WRITE,&hKey))
 	{
 		return -1; // Couldn't open or create key
 	}
@@ -661,9 +649,68 @@ const char *CGlobalSettings::GetConfigDirectory()
 	return GetCvsDir(cvs_config_dir,sizeof(cvs_config_dir));
 }
 
-const char *CGlobalSettings::GetLibraryDirectory()
+const char *CGlobalSettings::GetLibraryDirectory(GLDType type)
 {
-	return GetCvsDir(cvs_library_dir,sizeof(cvs_library_dir));
+	/* At some point replace this with something more complex.  For now
+	   it serves the purpose */
+	const char *cvsDir = GetCvsDir(cvs_library_dir,sizeof(cvs_library_dir));
+	static const char *cvsDirProtocols = NULL;
+	static const char *cvsDirTriggers = NULL;
+	static const char *cvsDirXdiff = NULL;
+	static const char *cvsDirMdns = NULL;
+	static const char *cvsDirDatabase = NULL;
+	switch(type)
+	{
+		case GLDLib:
+			return cvsDir;
+		case GLDProtocols:
+			if(!cvsDirProtocols)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/protocols";
+				cvsDirProtocols = strdup(cv.c_str());
+			}
+			return cvsDirProtocols;
+		case GLDTriggers:
+			if(!cvsDirTriggers)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/triggers";
+				cvsDirTriggers = strdup(cv.c_str());
+			}
+			return cvsDirTriggers;
+		case GLDXdiff:
+			if(!cvsDirXdiff)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/xdiff";
+				cvsDirXdiff = strdup(cv.c_str());
+			}
+			return cvsDirXdiff;
+		case GLDMdns:
+			if(!cvsDirMdns)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/mdns";
+				cvsDirMdns = strdup(cv.c_str());
+			}
+			return cvsDirMdns;
+		case GLDDatabase:
+			if(!cvsDirDatabase)
+			{
+				cvs::string cv;
+				cv = cvsDir;
+				cv += "/database";
+				cvsDirDatabase = strdup(cv.c_str());
+			}
+			return cvsDirDatabase;
+		default:
+			return cvsDir;
+	}
 }
 
 bool CGlobalSettings::SetConfigDirectory(const char *directory)
@@ -686,22 +733,32 @@ const char *CGlobalSettings::GetCvsCommand()
 {
 	if(!*cvs_command) /* Only do this once */
 	{
-		if(CGlobalSettings::GetGlobalValue("cvsnt","PServer","InstallPath",cvs_command,sizeof(cvs_command)) &&
-			CGlobalSettings::GetUserValue("cvsnt","PServer","InstallPath",cvs_command,sizeof(cvs_command)))
+		if (GetModuleFileNameA(GetModuleHandleA("cvstools.dll"), cvs_command, sizeof(cvs_command)))
 		{
-			if (GetModuleFileNameA(NULL, cvs_command, sizeof(cvs_command)))
-			{
-				char *p;
+			char *p;
 
-				p = strrchr(cvs_command, '\\');
-				if(p)
-					*p = '\0';
-				else
-					cvs_command[0] = '\0';
-			}
+			p = strrchr(cvs_command, '\\');
+			if(p)
+				*p = '\0';
+			else
+				cvs_command[0] = '\0';
 		}
 		GetShortPathNameA(cvs_command,cvs_command,sizeof(cvs_command));
 		strcat(cvs_command,"\\cvs.exe");
+
+		if(!CFileAccess::exists(cvs_command))
+		{
+			if(!CGlobalSettings::GetGlobalValue("cvsnt","PServer","InstallPath",cvs_command,sizeof(cvs_command)) ||
+			   !CGlobalSettings::GetUserValue("cvsnt","PServer","InstallPath",cvs_command,sizeof(cvs_command)))
+			{
+				GetShortPathNameA(cvs_command,cvs_command,sizeof(cvs_command));
+				strcat(cvs_command,"\\cvs.exe");
+				if(!CFileAccess::exists(cvs_command))
+					*cvs_command='\0';
+			}
+		}
+		if(!*cvs_command)
+			strcpy(cvs_command,"cvs.exe");
 	}
 	return cvs_command;
 }
@@ -711,3 +768,106 @@ bool CGlobalSettings::SetCvsCommand(const char *command)
 	return false; // Not on win32
 }
 
+// Basically Microsoft 118626
+// Needed for vista as it fakes the admin rights on the registry and screws everything up
+bool CGlobalSettings::isAdmin()
+{
+	static int isAd = 0;
+	bool   fReturn         = false;
+	DWORD  dwStatus;
+	DWORD  dwAccessMask;
+	DWORD  dwAccessDesired;
+	DWORD  dwACLSize;
+	DWORD  dwStructureSize = sizeof(PRIVILEGE_SET);
+	PACL   pACL            = NULL;
+	PSID   psidAdmin       = NULL;
+
+	HANDLE hToken              = NULL;
+	HANDLE hImpersonationToken = NULL;
+
+	PRIVILEGE_SET   ps;
+	GENERIC_MAPPING GenericMapping;
+
+	PSECURITY_DESCRIPTOR     psdAdmin           = NULL;
+	SID_IDENTIFIER_AUTHORITY SystemSidAuthority = SECURITY_NT_AUTHORITY;
+
+	if(isAd)
+		return isAd>0?true:false;
+
+	__try
+	{
+		if (!OpenThreadToken(GetCurrentThread(), TOKEN_DUPLICATE|TOKEN_QUERY, TRUE, &hToken))
+		{
+			if (GetLastError() != ERROR_NO_TOKEN)
+				__leave;
+
+			if (!OpenProcessToken(GetCurrentProcess(), TOKEN_DUPLICATE|TOKEN_QUERY, &hToken))
+				__leave;
+		}
+
+		if (!DuplicateToken (hToken, SecurityImpersonation, &hImpersonationToken))
+			__leave;
+
+
+		if (!AllocateAndInitializeSid(&SystemSidAuthority, 2, SECURITY_BUILTIN_DOMAIN_RID,DOMAIN_ALIAS_RID_ADMINS,0, 0, 0, 0, 0, 0, &psidAdmin))
+			__leave;
+
+		psdAdmin = LocalAlloc(LPTR, SECURITY_DESCRIPTOR_MIN_LENGTH);
+		if (psdAdmin == NULL)
+			__leave;
+
+		if (!InitializeSecurityDescriptor(psdAdmin, SECURITY_DESCRIPTOR_REVISION))
+			__leave;
+
+		// Compute size needed for the ACL.
+		dwACLSize = sizeof(ACL) + sizeof(ACCESS_ALLOWED_ACE) + GetLengthSid(psidAdmin) - sizeof(DWORD);
+
+		pACL = (PACL)LocalAlloc(LPTR, dwACLSize);
+		if (pACL == NULL)
+			__leave;
+
+		if (!InitializeAcl(pACL, dwACLSize, ACL_REVISION2))
+			__leave;
+
+		dwAccessMask = ACCESS_READ | ACCESS_WRITE;
+
+		if (!AddAccessAllowedAce(pACL, ACL_REVISION2, dwAccessMask, psidAdmin))
+			__leave;
+
+		if (!SetSecurityDescriptorDacl(psdAdmin, TRUE, pACL, FALSE))
+			__leave;
+
+		SetSecurityDescriptorGroup(psdAdmin, psidAdmin, FALSE);
+		SetSecurityDescriptorOwner(psdAdmin, psidAdmin, FALSE);
+
+		if (!IsValidSecurityDescriptor(psdAdmin))
+			__leave;
+
+		dwAccessDesired = ACCESS_READ;
+
+		GenericMapping.GenericRead    = ACCESS_READ;
+		GenericMapping.GenericWrite   = ACCESS_WRITE;
+		GenericMapping.GenericExecute = 0;
+		GenericMapping.GenericAll     = ACCESS_READ | ACCESS_WRITE;
+
+		BOOL bRet;
+		if (!AccessCheck(psdAdmin, hImpersonationToken, dwAccessDesired,
+						&GenericMapping, &ps, &dwStructureSize, &dwStatus,
+						&bRet))
+			__leave;
+		fReturn = bRet?true:false;
+	}
+	__finally
+	{
+		// Clean up.
+		if (pACL) LocalFree(pACL);
+		if (psdAdmin) LocalFree(psdAdmin);
+		if (psidAdmin) FreeSid(psidAdmin);
+		if (hImpersonationToken) CloseHandle (hImpersonationToken);
+		if (hToken) CloseHandle (hToken);
+	}
+
+	isAd=fReturn?1:-1;
+
+	return fReturn;
+}
