@@ -76,7 +76,7 @@ int no_discards;
 int binary_input;
 int binary_output;
 
-encoding_type encoding = {0};
+diff_encoding_type encoding = {0};
 
 /* Return a string containing the command options with which diff was invoked.
    Spaces appear between what were separate ARGV-elements.
@@ -165,7 +165,7 @@ add_exclude_file (name)
   f.name = optarg;
   f.desc = (strcmp (optarg, "-") == 0
 	    ? STDIN_FILENO
-	    : open (optarg, O_RDONLY, 0));
+		: callbacks?callbacks->open(optarg, O_RDONLY, 0):open(optarg, O_RDONLY, 0));
   if (f.desc < 0 || fstat (f.desc, &f.stat) != 0)
     return -1;
 
@@ -690,9 +690,9 @@ int diff_run (int argc, char *argv[], const char *out, const struct diff_callbac
 	  /* A diff which is full of ^Z and such isn't going to work
 	     very well in text mode.  */
 	  if (binary_output)
-	    outfile = fopen (out, "wb");
+		  outfile = callbacks?callbacks->fopen(out, "wb"):fopen(out, "wb");
 	  else
-	    outfile = fopen (out, "w");
+		  outfile = callbacks?callbacks->fopen(out, "wb"):fopen(out, "w");
 	  if (outfile == NULL)
 	    {
 	      perror_with_name ("could not open output file");
@@ -1033,7 +1033,7 @@ compare_files (dir0, name0, dir1, name1, depth)
 		}
 	    }
 	  else
-	    stat_result = stat (inf[i].name, &inf[i].stat);
+		  stat_result = callbacks?callbacks->stat(inf[i].name, &inf[i].stat):stat(inf[i].name, &inf[i].stat);
 
 	  if (stat_result != 0)
 	    {
@@ -1166,7 +1166,7 @@ compare_files (dir0, name0, dir1, name1, depth)
       /* Open the files and record their descriptors.  */
 
       if (inf[0].desc == -2)
-	if ((inf[0].desc = open (inf[0].name, O_RDONLY, 0)) < 0)
+	    if ((inf[0].desc = callbacks?callbacks->open(inf[0].name, O_RDONLY, 0):open(inf[0].name, O_RDONLY, 0)) < 0)
 	  {
 	    perror_with_name (inf[0].name);
 	    failed = 1;
@@ -1175,7 +1175,7 @@ compare_files (dir0, name0, dir1, name1, depth)
 	{
 	  if (same_files)
 	    inf[1].desc = inf[0].desc;
-	  else if ((inf[1].desc = open (inf[1].name, O_RDONLY, 0)) < 0)
+	  else if ((inf[1].desc = callbacks?callbacks->open(inf[1].name, O_RDONLY, 0):open(inf[1].name, O_RDONLY, 0)) < 0)
 	    {
 	      perror_with_name (inf[1].name);
 	      failed = 1;
