@@ -418,7 +418,7 @@ int diff3_run (int argc, char **argv, const char *out, const struct diff_callbac
   for (i = 0; i < 3; i++)
     if (strcmp (file[i], "-") != 0)
       {
-	if (stat (file[i], &statb) < 0)
+	  if ((callbacks?callbacks->stat(file[i], &statb):stat(file[i], &statb)) < 0)
 	  {
 	    perror_with_name (file[i]);
 	    return 2;
@@ -444,7 +444,7 @@ int diff3_run (int argc, char **argv, const char *out, const struct diff_callbac
 	outfile = stdout;
       else
 	{
-	  outfile = fopen (out, "w");
+	  outfile = callbacks?callbacks->fopen(out,"w"):fopen(out, "w");
 	  if (outfile == NULL)
 	    {
 	      perror_with_name ("could not open output file");
@@ -484,7 +484,7 @@ int diff3_run (int argc, char **argv, const char *out, const struct diff_callbac
 			       tag_strings[0], tag_strings[1], tag_strings[2]);
   else if (merge)
     {
-      FILE *mfp = fopen (file[rev_mapping[FILE0]], "r");
+      FILE *mfp = callbacks?callbacks->fopen(file[rev_mapping[FILE0]], "r"):fopen(file[rev_mapping[FILE0]], "r");
       if (! mfp)
 	diff3_perror_with_exit (file[rev_mapping[FILE0]]);
       conflicts_found = output_diff3_merge (mfp, diff3, mapping, rev_mapping,
@@ -1336,7 +1336,7 @@ read_diff (filea, fileb, output_placement)
   if (wstatus == 2)
     diff3_fatal ("subsidiary diff failed");
 
-  if (-1 == (fd = open (diffout, O_RDONLY, 0)))
+  if (-1 == (fd = callbacks?callbacks->open(diffout, O_RDONLY, 0):open(diffout, O_RDONLY, 0)))
     diff3_fatal ("could not open temporary diff file");
 
   current_chunk_size = 8 * 1024;
