@@ -80,7 +80,7 @@ static void prepare_text_end PARAMS((struct file_data *));
 
 #define binary_file_p(buf, size) (encoding.encoding || memchr (buf, '\0', size) != 0)
 
-extern encoding_type encoding; /* Override detection if --encoding passed */
+extern diff_encoding_type encoding; /* Override detection if --encoding passed */
 
 /* Get ready to read the current file.
    Return nonzero if SKIP_TEST is zero,
@@ -183,7 +183,7 @@ slurp (current, binary)
 			char *newbuf = NULL;
 			size_t newsize;
 
-			begin_encoding(&encoding,ENCODING_UTF8);
+			begin_encoding(&encoding);
 			if(convert_encoding(current->buffer,current->buffered_chars,&newbuf, &newsize))
 			{
 				free(current->buffer);
