@@ -324,7 +324,7 @@ bool CloseLockClient(CSocketIOPtr s)
 		//
 		// remove_if doesn't work on maps so we end up with trickery
 		// like this...
-		LockClientMapType::iterator c,d;
+/*		LockClientMapType::iterator c,d;
 		for (c=LockClientMap.begin(); c!=LockClientMap.end();)
 		{
 		  if(!c->second.endtime.iszero())
@@ -345,6 +345,8 @@ bool CloseLockClient(CSocketIOPtr s)
 		  else
 		    ++c;
 		}
+		*/
+		LockClientMap.erase(LockClientMap.find(client));
 		DEBUG("%d clients left\n",(int)LockClientMap.size());
 		/* Life is much easier on a vector */
 		size_t pos = std::partition(TransactionList.begin(), TransactionList.end(), IsWantedTransaction()) - TransactionList.begin();
@@ -786,11 +788,11 @@ bool DoVersion(CSocketIOPtr s,size_t client, char *param)
 		s->printf("001 FAIL Do not own lock id %u\n",(unsigned)lockId);
 		return false;
 	}
-	
+
 	VersionMapType& ver = LockMap[lockId].versions;
 
 	if(ver.find(branch)==ver.end())
-	{
+	{ 
 		s->printf("000 OK\n");
 		DEBUG("(#%d) Version request on lock %u (%s)\n",(int)client,(unsigned)lockId,branch);
 	}
