@@ -38,7 +38,9 @@
 
 bool g_bStop = false;
 extern bool g_bTestMode;
+#ifdef HAVE_MDNS
 bool use_mdns = true;
+#endif
 static int m_port;
 static int m_pserver_port;
 
@@ -89,6 +91,7 @@ static void *thread_proc(void* param)
 #endif
 }
 
+#ifdef HAVE_MDNS
 static void _mdns_thread_proc(void* param)
 {
 	int nResp;
@@ -142,7 +145,7 @@ static void _mdns_thread_proc(void* param)
 			strcpy(serverName,"unknown");
 	}
 
-	CMdnsHelperBase *mdns = CMdnsHelperBase::Alloc(eResp,CGlobalSettings::GetLibraryDirectory());
+	CMdnsHelperBase *mdns = CMdnsHelperBase::Alloc(eResp,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDMdns));
 
 	if(mdns && !mdns->open())
 	{
@@ -180,7 +183,7 @@ static void *mdns_thread_proc(void* param)
 	return NULL;
 #endif
 }
-
+#endif
 
 static int start_thread(CSocketIO* sock)
 {
@@ -197,6 +200,7 @@ static int start_thread(CSocketIO* sock)
 #endif
 }
 
+#ifdef HAVE_MDNS
 static int start_mdns_thread()
 {
 #ifdef _WIN32
@@ -211,6 +215,7 @@ static int start_mdns_thread()
 	// Don't do mdns
 #endif
 }
+#endif
 
 void run_server(int port, int seq, int local_only)
 {
@@ -219,11 +224,13 @@ void run_server(int port, int seq, int local_only)
 	int nResp;
 
 	m_port = port;
-	
+
+#ifdef HAVE_MDNS
     if(!CGlobalSettings::GetGlobalValue("cvsnt","PServer","ResponderType",nResp))
 		use_mdns = nResp?true:false;
 	else
 		use_mdns = true;
+#endif
 
 	sprintf(szLockServer,"%d",m_port);
 
@@ -268,12 +275,14 @@ void run_server(int port, int seq, int local_only)
 		NotifySCM(SERVICE_START_PENDING, 0, seq++);
 #endif
 
+#ifdef HAVE_MDNS
 	if(use_mdns)
 	{
 		m_pserver_port = 2401;
 		CGlobalSettings::GetGlobalValue("cvsnt","PServer","PServerPort", m_pserver_port);
 		start_mdns_thread();
 	}
+#endif
 
 	// Process running, wait for closedown
 	CServerIo::log(CServerIo::logNotice,"CVS Lock service initialised successfully");
