@@ -68,10 +68,20 @@ BOOL CALLBACK DllMain(HMODULE hModule, DWORD ul_reason_for_call, LPVOID lpReserv
 static const unsigned char cb64[65]="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 enum PIPES { PIPE_READ = 0, PIPE_WRITE = 1 };
 
-const struct server_interface *current_server;
+static const struct server_interface *_current_server;
 static int tcp_fd;
 static struct addrinfo *tcp_addrinfo, *tcp_active_addrinfo;
 
+void set_current_server(const struct server_interface *_cs)
+{
+  _current_server = _cs;
+}
+
+const struct server_interface *current_server()
+{
+  return _current_server;
+}
+
 /*
 ** encodeblock
 **
@@ -149,44 +159,14 @@ int get_tcp_fd()
 	return tcp_fd;
 }
 
-int get_user_config_data(const char *key, const char *value, char *buffer, int buffer_len)
-{
-	return current_server->get_user_config_data(current_server,key,value,buffer,buffer_len);
-}
-
-int set_user_config_data(const char *key, const char *value, const char *buffer)
-{
-	return current_server->set_user_config_data(current_server,key,value,buffer);
-}
-
-int enum_user_config_data(const char *key, int value_num, char *value, int value_len, char *buffer, int buffer_len)
-{
-	return current_server->enum_user_config_data(current_server,key,value_num,value,value_len,buffer,buffer_len);
-}
-
-int get_server_config_data(const char *key, const char *value, char *buffer, int buffer_len)
-{
-	return current_server->get_server_config_data(current_server,key,value,buffer,buffer_len);
-}
-
-int set_server_config_data(const char *key, const char *value, const char *buffer)
-{
-	return current_server->set_server_config_data(current_server,key,value,buffer);
-}
-
-int enum_server_config_data(const char *key, int value_num, char *value, int value_len, char *buffer, int buffer_len)
-{
-	return current_server->enum_server_config_data(current_server,key,value_num,value,value_len,buffer,buffer_len);
-}
-
 const char *enum_protocols(int *context, enum proto_type type)
 {
-	return current_server->enumerate_protocols(current_server,context,type);
+	return _current_server->enumerate_protocols(_current_server,context,type);
 }
 
 int set_encrypted_channel(int encrypt)
 {
-	return current_server->set_encrypted_channel(current_server,encrypt);
+	return _current_server->set_encrypted_channel(_current_server,encrypt);
 }
 
 int server_error(int fatal, const char *fmt, ...)
@@ -200,7 +180,7 @@ int server_error(int fatal, const char *fmt, ...)
 
 	va_end(va);
 
-	return current_server->error(current_server, fatal, temp);
+	return _current_server->error(_current_server, fatal, temp);
 }
 
 static int tcp_connect_direct(const cvsroot *cvsroot)
@@ -270,9 +250,236 @@ static int tcp_connect_http(const cvsroot *cvsroot)
 	return 0;
 }
 
-static int tcp_connect_cgi(const cvsroot *cvsroot)
+static int tcp_connect_socks5(const cvsroot *cvsroot)
 {
-	return -1;
+	int socks_sock;
+	const char *port;
+	unsigned short u_port;
+	unsigned char resp[1024];
+
+	port = cvsroot->proxyport;
+	if(!port)
+		port="1080";
+
+	if(!cvsroot->proxy)
+		server_error(1,"Proxy name must be specified for SOCKS tunnelling");
+	
+	socks_sock = tcp_connect_bind(cvsroot->proxy, port, 0, 0);
+	if(socks_sock<0)
+		return socks_sock;
+
+	port = get_default_port(cvsroot);
+	u_port = atoi(port);
+
+	if(cvsroot->proxyuser && cvsroot->proxyuser[0])
+	{
+		unsigned char init[4]= { 5, 2, 2, 0 };
+		tcp_write(init,sizeof(init));
+	}
+	else
+	{
+		unsigned char init[3] = { 5, 1, 0 };
+		tcp_write(init,sizeof(init));
+	}
+	if(tcp_read(resp,2)!=2)
+		server_error(1,"Unable to communicate with SOCKS server");
+
+	if(resp[1]==0xFF)
+	{
+		server_error(1,"Socks server refused to talk to us");
+	}
+	if(resp[1]==2)
+	{
+		unsigned char auth[1024];
+		int l = 0, s;
+		auth[l++]=1;
+		s=cvsroot->proxyuser?strlen(cvsroot->proxyuser):0;
+		if(s>255) s=255;
+		auth[l++]=(unsigned char)s;
+		if(s)
+			memcpy(&auth[l],cvsroot->proxyuser,s);
+		l+=s;
+		s=cvsroot->proxypassword?strlen(cvsroot->proxypassword):0;
+		if(s>255) s=255;
+		auth[l++]=(unsigned char)s;
+		if(s)
+			memcpy(&auth[l],cvsroot->proxypassword,s);
+		l+=s;
+		tcp_write(auth,l);
+		if(tcp_read(resp,2)!=2)
+			server_error(1,"Unable to communicate with SOCKS server");
+		if(resp[1])
+		{
+			server_error(1,"Socks server rejected authentication: bad username/password?");
+		}
+	}
+
+	unsigned char request[1024];
+	int l=0,s;
+	request[l++]=5;
+	request[l++]=1;
+	request[l++]=0;
+	request[l++]=3;
+	s=strlen(cvsroot->hostname);
+	if(s>255) s=255;
+	request[l++]=s;
+	if(s)
+		memcpy(&request[l],cvsroot->hostname,s);
+	l+=s;
+	*(unsigned short *)&request[l]=htons(u_port);
+	l+=2;
+
+	tcp_write(request,l);
+	if(tcp_read(resp,4)!=4)
+		server_error(1,"Unable to communicate with SOCKS server");
+	switch(resp[1])
+	{
+	case 0:
+		break;
+	case 1:
+		server_error(1,"General SOCKS server failure");
+		break;
+	case 2:
+		server_error(1,"SOCKS error: Connection not allowed by ruleset");
+		break;
+	case 3:
+		server_error(1,"SOCKS error: Remote Network unreachable");
+		break;
+	case 4:
+		server_error(1,"SOCKS error: Remote Host unreachable");
+		break;
+	case 5:
+		server_error(1,"SOCKS error: Connection refused by remote host");
+		break;
+	case 6:
+		server_error(1,"SOCKS error: TTL expired");
+		break;
+	case 7:
+		server_error(1,"SOCKS error: Command not supported");
+		break;
+	case 8:
+		server_error(1,"SOCKS error: Address type not supported");
+		break;
+	default:
+		server_error(1,"SOCKS error: unknown error %02x",resp[1]);
+		break;
+	}
+
+	char addr[300];
+	switch(resp[3])
+	{
+	case 0: // IPV4
+	case 1: // IPV4, sent by dante (broken??)
+		tcp_read(&resp[4],6);
+		snprintf(addr,sizeof(addr),"%d.%d.%d.%d",resp[4],resp[5],resp[6],resp[7]);
+		u_port=ntohs(*(unsigned short *)&resp[8]);
+		break;
+	case 3: // Domain name
+		tcp_read(&resp[4],1);
+		if(resp[4])
+		{
+			tcp_read(&resp[5],resp[4]+2);
+			memcpy(addr,&resp[5],resp[4]);
+			addr[resp[4]='\0'];
+		}
+		else
+		{
+			addr[0]='\0';
+		}
+		u_port=ntohs(*(unsigned short *)&resp[resp[4]+5]);
+		break;
+	case 4: // IPV6
+		tcp_read(&resp[4],18);
+		snprintf(addr,sizeof(addr),"%02x%02x::%02x%02x::%02x%02x::%02x%02x::%02x%02x::%02x%02x::%02x%02x::%02x%02x",resp[4],resp[5],resp[6],resp[7],resp[8],resp[9],resp[10],resp[11],resp[12],resp[13],resp[14],resp[15],resp[16],resp[17],resp[18],resp[19]);
+		u_port=ntohs(*(unsigned short *)&resp[20]);
+		break;
+	default:
+		server_error(1,"Unknown address type (%02x) sent by socks server",resp[3]);
+		break;
+	}
+
+	return 0;
+}
+
+static int tcp_connect_socks4(const cvsroot *cvsroot)
+{
+	int socks_sock;
+	const char *port;
+	unsigned short u_port;
+	unsigned char resp[1024];
+
+	port = cvsroot->proxyport;
+	if(!port)
+		port="1080";
+
+	if(!cvsroot->proxy)
+		server_error(1,"Proxy name must be specified for SOCKS tunnelling");
+
+	if(cvsroot->proxypassword)
+		server_error(1,"SOCKS4 does not support password authentication");
+    	
+	socks_sock = tcp_connect_bind(cvsroot->proxy, port, 0, 0);
+	if(socks_sock<0)
+		return socks_sock;
+
+	port = get_default_port(cvsroot);
+	u_port = atoi(port);
+
+	resp[0]=4;
+	resp[1]=1;
+	*(unsigned short *)&resp[2]=htons(u_port);
+
+	struct addrinfo hint = {0};
+	int res;
+	hint.ai_protocol=IPPROTO_TCP;
+	hint.ai_socktype=SOCK_STREAM;
+	if((res=getaddrinfo(cvsroot->hostname,port,&hint,&tcp_addrinfo))!=0)
+	{
+		server_error (1,"Error connecting to host %s: %s\n", cvsroot->hostname, gai_strerror(socket_errno));
+		return -1;
+	}
+
+	sockaddr_in* sin = (sockaddr_in*)tcp_addrinfo->ai_addr;
+	memcpy(&resp[4],&sin->sin_addr.s_addr,4);
+
+	freeaddrinfo(tcp_addrinfo);
+
+	int l = 8;
+	if(cvsroot->proxyuser)
+	{
+		l+=strlen(cvsroot->proxyuser);
+		strcpy((char*)&resp[8],cvsroot->proxyuser);
+	}
+	else
+	{
+		const char *u = get_username(cvsroot);
+		l+=strlen(u);
+		strcpy((char*)&resp[8],u);
+	}
+	l++;
+
+	tcp_write(resp,l);
+	if(tcp_read(resp,8)!=8)
+		server_error(1,"Unable to communicate with SOCKS server");
+
+	switch(resp[1])
+	{
+	case 90:
+		break;
+	case 91:
+		server_error(1,"SOCKS4 request failed");
+		break;
+	case 92:
+		server_error(1,"SOCKS4 ident lookup failed");
+		break;
+	case 93:
+		server_error(1,"SOCKS4 ident reports different identities");
+		break;
+	default:
+		server_error(1,"SOCKS4 error %02x",resp[1]);
+	}
+
+	return 0;
 }
 
 int tcp_connect(const cvsroot *cvsroot)
@@ -285,8 +492,12 @@ int tcp_connect(const cvsroot *cvsroot)
 		return tcp_connect_direct(cvsroot);
 	if(!strcasecmp(protocol,"HTTP"))
 		return tcp_connect_http(cvsroot);
-	if(!strcasecmp(protocol,"CGI"))
-		return tcp_connect_cgi(cvsroot);
+	if(!strcasecmp(protocol,"SOCKS5"))
+		return tcp_connect_socks5(cvsroot);
+	if(!strcasecmp(protocol,"SOCKS"))
+		return tcp_connect_socks5(cvsroot);
+	if(!strcasecmp(protocol,"SOCKS4"))
+		return tcp_connect_socks4(cvsroot);
 	tcp_fd = -1;
 	server_error(1, "Unsupported tunnelling protocol '%s' specified",protocol);
 	return -1;
@@ -398,7 +609,7 @@ int tcp_disconnect()
 int tcp_read(void *data, int length)
 {
 	if(!tcp_fd) /* Using stdin/out, probably */
-		return read(current_server->in_fd,data,length);
+		return read(_current_server->in_fd,data,length);
 	else
 	{
 		CServerIo::trace(4,"tcp_read(%d)",length);
@@ -414,7 +625,7 @@ int tcp_read(void *data, int length)
 int tcp_write(const void *data, int length)
 {
 	if(!tcp_fd) /* Using stdin/out, probably */
-		return write(current_server->out_fd,data,length);
+		return write(_current_server->out_fd,data,length);
 	else
 	{
 		CServerIo::trace(4,"tcp_write(%d)",length);
@@ -479,7 +690,7 @@ int server_getc(const struct protocol_interface *protocol)
 	}
 	else
 	{
-		if(read(current_server->in_fd,&c,1)<1)
+		if(read(_current_server->in_fd,&c,1)<1)
 			return EOF;
 		return c;
 	}
@@ -522,7 +733,7 @@ int server_printf(const char *fmt, ...)
 
 	va_end(va);
 
-	return write(current_server->out_fd,temp,strlen(temp));
+	return write(_current_server->out_fd,temp,strlen(temp));
 }
 
 #ifdef _WIN32
@@ -743,17 +954,17 @@ static BOOL CALLBACK ConfigDlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM l
 {
 	char value[MAX_PATH];
 	int nSel;
-	struct ui_interface *ui = (struct ui_interface*)GetWindowLongPtr(hWnd,GWL_USERDATA);
+	struct plugin_interface *ui = (struct plugin_interface*)GetWindowLongPtr(hWnd,GWL_USERDATA);
 
 	switch(uMsg)
 	{
 	case WM_INITDIALOG:
 		{
 			SetWindowLongPtr(hWnd,GWL_USERDATA,lParam);
-			ui = (struct ui_interface*)lParam;
+			ui = (struct plugin_interface*)lParam;
 			SetWindowText(hWnd,ui->description);
 			nSel = 1;
-			if(!get_server_config_data("Plugins",ui->key,value,sizeof(value)))
+			if(!CGlobalSettings::GetGlobalValue("cvsnt","Plugins",ui->key,value,sizeof(value)))
 				nSel = atoi(value);
 			SendDlgItemMessage(hWnd,IDC_CHECK1,BM_SETCHECK,nSel,0);
 		}
@@ -764,7 +975,7 @@ static BOOL CALLBACK ConfigDlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM l
 		case IDOK:
 			nSel=SendDlgItemMessage(hWnd,IDC_CHECK1,BM_GETCHECK,0,0);
 			snprintf(value,sizeof(value),"%d",nSel);
-            set_server_config_data("Plugins",ui->key,value);
+            CGlobalSettings::SetGlobalValue("cvsnt","Plugins",ui->key,value);
 		case IDCANCEL:
 			EndDialog(hWnd,LOWORD(wParam));
 			return TRUE;
@@ -774,7 +985,7 @@ static BOOL CALLBACK ConfigDlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM l
 	return FALSE;
 }
 
-int win32config(const struct ui_interface *ui, void *wnd)
+int win32config(const struct plugin_interface *ui, void *wnd)
 {
 	HWND hWnd = (HWND)wnd;
 	int ret = DialogBoxParam(g_hInst, MAKEINTRESOURCE(IDD_DIALOG2), hWnd, ConfigDlgProc,(LPARAM)ui);
