@@ -29,7 +29,7 @@
 #endif
 #include <ctype.h>
 
-#define MODULE enum_protocol
+#define MODULE enum
 
 #include "common.h"
 #include "../version.h"
