@@ -30,7 +30,7 @@
 #include <netdb.h>
 #endif
 
-#define MODULE ext_protocol
+#define MODULE ext
 
 #include "common.h"
 #include "../version.h"
