@@ -30,7 +30,7 @@
 #include <netdb.h>
 #endif
 
-#define MODULE fork_protocol
+#define MODULE fork
 
 #include "common.h"
 #include "../version.h"
