@@ -39,7 +39,7 @@
 #define sock_strerror strerror
 #endif
 
-#define MODULE gserver_protocol
+#define MODULE gserver
 
 #include "common.h"
 #include "../version.h"
