@@ -26,7 +26,7 @@
 #include <unistd.h>
 #endif
 
-#define MODULE pserver_protocol
+#define MODULE pserver
 
 #include "common.h"
 #include "../version.h"
