@@ -27,7 +27,7 @@
 #include <unistd.h>
 #endif
 
-#define MODULE server_protocol
+#define MODULE server
 
 #include "common.h"
 #include "../version.h"
