@@ -31,7 +31,7 @@
 #include <openssl/ssl.h>
 #include <openssl/err.h>
 
-#define MODULE sserver_protocol
+#define MODULE sserver
 
 #include "common.h"
 #include "../version.h"
@@ -51,7 +51,6 @@ static int sserver_read_data(const struct protocol_interface *protocol, void *da
 static int sserver_write_data(const struct protocol_interface *protocol, const void *data, int length);
 static int sserver_flush_data(const struct protocol_interface *protocol);
 static int sserver_shutdown(const struct protocol_interface *protocol);
-static int sserver_wrap(const struct protocol_interface *protocol, int unwrap, int encrypt, const void *input, int size, void *output, int *newsize);
 static int sserver_validate_keyword(const struct protocol_interface *protocol, cvsroot *root, const char *keyword, const char *value);
 static const char *sserver_get_keyword_help(const struct protocol_interface *protocol);
 
@@ -99,7 +98,7 @@ struct protocol_interface sserver_protocol_interface =
 	sserver_disconnect,
 	sserver_login,
 	sserver_logout,
-	sserver_wrap,
+	NULL, /* wrap */
 	sserver_auth_protocol_connect,
 	sserver_read_data,
 	sserver_write_data,
@@ -221,7 +220,7 @@ int sserver_connect(const struct protocol_interface *protocol, int verify_only)
 		if(sserver_get_user_password(username,current_server()->current_root->hostname,current_server()->current_root->port,current_server()->current_root->directory,crypt_password,sizeof(crypt_password)))
 		{
 			/* Using null password - trace something out here */
-			server_error(0,"Empty password used - try 'cvs login' with a real password\n");
+			server_error(0,"Using an empty password; you may need to do 'cvs login' with a real password\n");
 			strncpy(crypt_password,scramble.Scramble(""),sizeof(crypt_password));
 		}
 	}
@@ -262,17 +261,17 @@ int sserver_connect(const struct protocol_interface *protocol, int verify_only)
 	{
 		if((err=SSL_CTX_use_certificate_file(ctx,key,SSL_FILETYPE_PEM))<1)
 		{
-			sserver_error("Couldn't read client certificate", err);
+			sserver_error("Unable to read/load the client certificate", err);
 			return CVSPROTO_FAIL;
 		}
 		if((err=SSL_CTX_use_PrivateKey_file(ctx,key,SSL_FILETYPE_PEM))<1)
 		{
-			sserver_error("Couldn't read client certificate", err);
+			sserver_error("Unable to read/load the client private key", err);
 			return CVSPROTO_FAIL;
 		}
 		if(!SSL_CTX_check_private_key(ctx))
 		{
-			sserver_error("Client certificate verification failed", err);
+			sserver_error("Client certificate failed verification", err);
 			return CVSPROTO_FAIL;
 		}
 	}
@@ -285,6 +284,7 @@ int sserver_connect(const struct protocol_interface *protocol, int verify_only)
 	SSL_set_fd (ssl, get_tcp_fd());
     if((err=SSL_connect (ssl))<1)
 	{
+		/* if the SSL connection failed, it is probably because the server hasn't got a valid cert/key so is unable to setup a SSL session */
 		sserver_error("SSL connection failed", err);
 		return CVSPROTO_FAIL;
 	}
@@ -395,7 +395,7 @@ int sserver_auth_protocol_connect(const struct protocol_interface *protocol, con
 		certonly = atoi(keyfile);
 	if(CGlobalSettings::GetGlobalValue("cvsnt","PServer","CertificateFile",certfile,sizeof(certfile)))
 	{
-		server_error(0,"E Couldn't get certificate file\n");
+		server_error(0,"E Configuration Error - CertificateFile not specified\n");
 		return CVSPROTO_FAIL;
 	}
 	if(CGlobalSettings::GetGlobalValue("cvsnt","PServer","PrivateKeyFile",keyfile,sizeof(keyfile)))
@@ -411,17 +411,17 @@ int sserver_auth_protocol_connect(const struct protocol_interface *protocol, con
 	ERR_get_error(); // Clear error stack
 	if((err=SSL_CTX_use_certificate_file(ctx, certfile ,SSL_FILETYPE_PEM))<1)
 	{
-		sserver_error("Couldn't read certificate", err);
+		sserver_error("Unable to read/load the server certificate", err);
 		return CVSPROTO_FAIL;
 	}
 	if((err=SSL_CTX_use_PrivateKey_file(ctx, keyfile ,SSL_FILETYPE_PEM))<1)
 	{
-		sserver_error("Couldn't read certificate", err);
+		sserver_error("Unable to read/load the server private key", err);
 		return CVSPROTO_FAIL;
 	}
 	if(!SSL_CTX_check_private_key(ctx))
 	{
-		sserver_error("Certificate verification failed", err);
+		sserver_error("Server certificate failed verification", err);
 		return CVSPROTO_FAIL;
 	}
 	SSL_CTX_set_verify(ctx,SSL_VERIFY_PEER,NULL); /* Check verify result below */
@@ -623,13 +623,6 @@ int sserver_printf(char *fmt, ...)
 	return sserver_write_data(NULL,temp,strlen(temp));
 }
 
-int sserver_wrap(const struct protocol_interface *protocol, int unwrap, int encrypt, const void *input, int size, void *output, int *newsize)
-{
-	memcpy(output,input,size);
-	*newsize=size;
-	return 0;
-}
-
 int sserver_validate_keyword(const struct protocol_interface *protocol, cvsroot *root, const char *keyword, const char *value)
 {
    if(!strcasecmp(keyword,"version") || !strcasecmp(keyword,"ver"))
