@@ -28,7 +28,7 @@
 #include <Schnlsp.h>
 #include <lm.h>
 
-#define MODULE sspi_protocol
+#define MODULE sspi
 
 #include "common.h"
 #include "../version.h"
