@@ -17,7 +17,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#define MODULE sspi_protocol
+#define MODULE sspi
 
 #include "common.h"
 #include "ntlm/ntlm.h"
@@ -167,7 +167,7 @@ int sspi_connect(const struct protocol_interface *protocol, int verify_only)
 	if(strstr(protocols,"NTLM"))
 		proto="NTLM";
 	else
-	    server_error(1, "Can't authenticate - server and client cannot agree on an authentication scheme (got '%s')",protocols);
+	    server_error(1, "Can't authenticate - server and client cannot agree on an authentication scheme (got '%s')\n",protocols);
 
 	if(!ClientAuthenticate(proto,user,password,domain,current_server()->current_root->hostname))
 	{
@@ -175,9 +175,9 @@ int sspi_connect(const struct protocol_interface *protocol, int verify_only)
 		   authenticate then fails at the server end.  Wierd huh? */
 
 		if(user)
-			server_error(1, "Can't authenticate - Username, Password or Domain is incorrect");
+			server_error(1, "Can't authenticate - Username, Password or Domain is incorrect\n");
 		else
-			server_error(1, "Can't authenticate - perhaps you need to login first?");
+			server_error(1, "Can't authenticate - perhaps you need to login first?\n");
 
 		return CVSPROTO_FAIL;
 	}
