@@ -1554,7 +1554,7 @@ packetizing_buffer_input (void *closure, char *data, int need, int size, int *go
 	tcount = ((outbuf[0] & 0xff) << 8) + (outbuf[1] & 0xff);
 
 	if (tcount > count)
-	    error (1, 0, "Input translation failure");
+		error (1, 0, "Input failure: data packet recieved is too short");
 
 	if (tcount > size)
 	{
