@@ -201,6 +201,9 @@ int checkout (int argc, char **argv)
 		break;
 	    case 'd':
 		where = xstrdup(optarg);
+#ifdef _WIN32
+		preparse_filename(where);
+#endif
 		if (shorten == -1)
 		    shorten = 1;
 		break;
@@ -277,6 +280,13 @@ int checkout (int argc, char **argv)
 		server_pathname_check(where);
 #endif
 
+	if(where && (!strcmp(where,"/")
+#ifdef _WIN32
+		|| !strcmp(where,"\\") || (strlen(where)<=3 && *where && where[1]==':')
+#endif
+		))
+		error(1, 0, "Cannot checkout onto the root directory");
+
     if (!is_rcs && !cat && !safe_location())
         error(1, 0, "Cannot check out files into the repository itself");
 
