@@ -1482,7 +1482,7 @@ static int commit_fileproc (void *callerdat, struct file_info *finfo)
 
 out:
 	xfree(options);
-    if (err != 0 || ci->status == T_UPTODATE)
+    if (err != 0/* || ci->status == T_UPTODATE*/)
     {
 	/* on failure, remove the file from ulist */
 	p = findnode_fn (ulist, finfo->file);
