@@ -559,7 +559,6 @@ static int diff_fileproc (void *callerdat, struct file_info *finfo)
 	    }
 	}
     }
-
     empty_file = diff_file_nodiff (finfo, vers, empty_file, default_branch);
     if (empty_file == DIFF_SAME || empty_file == DIFF_ERROR)
     {
@@ -929,13 +928,6 @@ static enum diff_file diff_file_nodiff(struct file_info *finfo, Vers_TS *vers, e
     if (use_rev1 == NULL
 	|| (vers->vn_user != NULL && strcmp (use_rev1, vers->vn_user) == 0))
     {
-	if (empty_file == DIFF_DIFFERENT
-	    && vers->ts_user != NULL
-	    && strcmp (vers->ts_rcs, vers->ts_user) == 0
-	    && (!(*options) || strcmp (options, vers->options) == 0))
-	{
-	    return DIFF_SAME;
-	}
 	if (use_rev1 == NULL
 	    && (vers->vn_user[0] != '0' || vers->vn_user[1] != '\0'))
 	{
@@ -944,6 +936,34 @@ static enum diff_file diff_file_nodiff(struct file_info *finfo, Vers_TS *vers, e
 	    else
 		use_rev1 = xstrdup (vers->vn_user);
 	}
+
+	if (empty_file == DIFF_DIFFERENT
+	    && vers->ts_user != NULL
+	    && strcmp (vers->ts_rcs, vers->ts_user) == 0)
+	{
+	    if((!*options) || !strcmp(options, vers->options))
+	    {
+	        return DIFF_SAME;
+	    }
+
+	    if(!isfile(finfo->file))
+	    {
+	        /* Checkout the file, which wasn't sent by the server, for
+	         * checking with different options */
+
+
+	        retcode = RCS_checkout (vers->srcfile, (char *) NULL,
+				    use_rev1, (char *) NULL,
+				    vers->options,
+				    finfo->file, (RCSCHECKOUTPROC) NULL,
+				    (void *) NULL, NULL);
+		if (retcode != 0)
+		{
+		    diff_mark_errors (retcode);
+		    return DIFF_DIFFERENT;
+		}
+	    }
+	}
     }
 
     /* If we already know that the file is being added or removed,
@@ -958,7 +978,7 @@ static enum diff_file diff_file_nodiff(struct file_info *finfo, Vers_TS *vers, e
 
     retcode = RCS_cmp_file (vers->srcfile, use_rev1,
 			    *options ? options : vers->options,
-			    finfo->file);
+			    finfo->file, 0);
 
     return retcode == 0 ? DIFF_SAME : DIFF_DIFFERENT;
 }
