@@ -63,10 +63,11 @@ static int force_tags;
 static int ignore_cvsignore;
 static int single_file;
 static int single_file_remove;
+static int hidden;
 
 static const char *const import_usage[] =
 {
-    "Usage: %s %s [-C] [-d] [-f] [-k subst] [-I ign] [-m msg] [-b branch]\n",
+    "Usage: %s %s [-C] [-d] [-f] [-h] [-k subst] [-I ign] [-m msg] [-b branch]\n",
 	"    [-W spec] [-n] [-F] repository [vendor-tag] [release-tags...]\n",
     "\t-C\tCreate CVS directories while importing.\n",
     "\t-d\tUse the file's modification time as the time of import.\n",
@@ -75,6 +76,9 @@ static const char *const import_usage[] =
     "\t-I ign\tMore files to ignore (! to reset, @ to skip .cvsignore).\n",
     "\t-b bra\tVendor branch id.\n",
     "\t-m msg\tLog message.\n",
+#ifdef _WIN32
+    "\t-h\tInclude hidden files.\n",
+#endif
     "\t-W spec\tWrappers specification line (! to reset).\n",
 	"\t-n\tDon't create vendor branch or release tags.\n",
     "(Specify the --help global option for a list of other help options)\n",
@@ -103,7 +107,7 @@ int import (int argc, char **argv)
 
     vbranch = xstrdup (CVSBRANCH);
     optind = 0;
-    while ((c = getopt (argc, argv, "+Qqdb:Cm:I:k:W:nfFR")) != -1)
+    while ((c = getopt (argc, argv, "+Qqdb:Cm:I:k:W:nfFRh")) != -1)
     {
 	switch (c)
 	{
@@ -152,6 +156,9 @@ int import (int argc, char **argv)
 			else
 				ign_add (optarg, 0);
 		break;
+	case 'h':
+		hidden = 1;
+		break;
         case 'k':
 		if(server_active && compat[compat_level].ignore_client_wrappers)
 			break;
@@ -551,6 +558,11 @@ static int import_descend (char *message, char *vtag, int targc, char *targv[])
 	{
 	    if (strcmp (dp->d_name, ".") == 0 || strcmp (dp->d_name, "..") == 0)
 		goto one_more_time_boys;
+#ifdef _WIN32
+	    if (!hidden && dp->d_hidden)
+		goto one_more_time_boys;
+#endif
+	    
 #ifdef SERVER_SUPPORT
 	    /* CVS directories are created in the temp directory by
 	       server.c because it doesn't special-case import.  So
