@@ -173,10 +173,14 @@ int info(int argc, char **argv)
 				break;
 			}
 		}
-		CZeroconf zc(eResp, CGlobalSettings::GetLibraryDirectory());
+		CZeroconf zc(eResp, CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDMdns));
 		const CZeroconf::server_struct_t *serv;
 
-		zc.BrowseForService(SERVICE,CZeroconf::zcAddress);
+		if(!zc.BrowseForService(SERVICE,CZeroconf::zcAddress))
+		{
+			printf("Unable to browse for servers.\n");
+			return 0;
+		}
 		bool first = true;
 		while((serv=zc.EnumServers(first))!=NULL)
 		{
