@@ -1209,19 +1209,24 @@ static struct revlist *log_expand_revlist (RCSNode *rcs, struct option_revlist *
 			   r->first, fn_root(rcs->path));
 		}
 	    }
-            
+           
 	    if (r->last == r->first || (r->last != NULL && r->first != NULL &&
                                         strcmp (r->last, r->first) == 0))
                 nr->last = xstrdup (nr->first);
-	    else if (r->last == NULL || isdigit ((unsigned char) r->last[0]))
+	    else if (r->last && isdigit ((unsigned char) r->last[0]))
 		nr->last = xstrdup (r->last);
 	    else
 	    {
-		if (RCS_nodeisbranch (rcs, r->last))
-		    nr->last = RCS_whatbranch (rcs, r->last);
+		if(!r->last)
+		  nr->last = RCS_branch_head(rcs,nr->first);
 		else
+		{
+		  if (RCS_nodeisbranch (rcs, r->last))
+		    nr->last = RCS_whatbranch (rcs, r->last);
+		  else
 		    nr->last = RCS_gettag (rcs, r->last, 1, (int *) NULL);
-		if (nr->last == NULL)
+		}
+	 	if (nr->last == NULL)
 		{
 			if(!quiet)
 			    error (0, 0, "warning: no revision `%s' in `%s'",
