@@ -63,7 +63,7 @@ int trace = 0;
 const char *trace_file;
 FILE *trace_file_fp;
 int allow_trace = 0;
-int remote_init = 0;
+const char *remote_init_root;
 int noexec = 0;
 int atomic_commits = 0;
 int no_reverse_dns = 0;
@@ -325,10 +325,8 @@ static const char *const opt_usage[] =
 	"    -a              Authenticate/sign all net traffic.\n",
 	"    -N              Supress network share error. (UNSUPPORTED OPTION)\n",
     "    -s VAR=VAL      Set CVS user variable.\n",
-#ifndef _WIN32
     "    -L              Override cvs library directory\n",
     "    -C              Override cvs configuration directory\n",
-#endif
 //	"    -R				 Set remapping file.\n",
 	"    -o[locale]      Translate between server and client locale.\n",
 	"                    Specifying a locale here overrides the default (autodetected on CVSNT 2.0.58+).\n",
@@ -596,8 +594,8 @@ static void read_global_config(void)
 		if(!CGlobalSettings::GetGlobalValue("cvsnt","PServer","AllowTrace",buffer,sizeof(buffer)))
 			allow_trace = atoi(buffer);
 
-		if(!CGlobalSettings::GetGlobalValue("cvsnt","PServer","RemoteInit",buffer,sizeof(buffer)))
-			remote_init = atoi(buffer);
+		if(!CGlobalSettings::GetGlobalValue("cvsnt","PServer","RemoteInitRoot",buffer,sizeof(buffer)))
+			remote_init_root = xstrdup(buffer);
 
 		n=0;
 		while(!CGlobalSettings::EnumGlobalValues("cvsnt","PServer",n++,token,sizeof(token),buffer,sizeof(buffer)))
@@ -697,6 +695,9 @@ int main (int argc, char **argv)
 #endif
 #if defined(WIN32) && defined(SERVER_SUPPORT)
 		{"win32_socket_io", required_argument, NULL, 8 },
+#endif
+#if defined(WIN32)
+		{"debug", 0, NULL, 9},
 #endif
         {0, 0, 0, 0}
     };
@@ -839,6 +840,11 @@ int main (int argc, char **argv)
 			case 7:
 				testserver = 1;
 				break;
+#endif
+#ifdef _WIN32
+			case 9:
+				_asm int 3
+				break;
 #endif
             case 1:
 	        /* --help-commands */
@@ -950,9 +956,12 @@ Copyright (c) 1989-2001 Brian Berliner, david d `zoo' zuhn, \n\
 		if (CVSroot_cmdline != NULL)
 		    xfree (CVSroot_cmdline);
 		CVSroot_cmdline = xstrdup (optarg);
+#ifdef _WIN32
+		preparse_filename(CVSroot_cmdline);
+#endif
 		if (free_CVSroot)
 		    xfree (CVSroot);
-		CVSroot = xstrdup (optarg);
+		CVSroot = xstrdup (CVSroot_cmdline);
 		free_CVSroot = 1;
 		cvs_update_env = 1;	/* need to update environment */
 		break;
@@ -1122,16 +1131,16 @@ Copyright (c) 1989-2001 Brian Berliner, david d `zoo' zuhn, \n\
 	setlocale(LC_ALL,"") || setlocale(LC_CTYPE,"");
 	if(cvs_locale)
 	{
-   	   if(setlocale(LC_ALL,cvs_locale) && setlocale(LC_CTYPE, cvs_locale))
+   	   if(!setlocale(LC_ALL,cvs_locale) && !setlocale(LC_CTYPE, cvs_locale))
 	      TRACE(3,"Unable to set client locale to '%s'",cvs_locale);
 	}
 	else if(server_active || UTF8_CLIENT)
 	{
 	   char loc[256];
-	   char *l = setlocale(LC_CTYPE,"");
+	   char *l = setlocale(LC_CTYPE,NULL);
 
 	   if(!l)
-		   l=setlocale(LC_ALL,"");
+		   l=setlocale(LC_ALL,NULL);
 
 	   if(l)
 	   {
@@ -1154,6 +1163,12 @@ Copyright (c) 1989-2001 Brian Berliner, david d `zoo' zuhn, \n\
 			TRACE(3,"utf8 locale successfully set");
 		}
 	}
+
+	if(server_active)
+		TRACE(3,"Server locale is %s", setlocale (LC_ALL,NULL));
+	else
+		TRACE(3,"Client locale is %s", setlocale (LC_ALL,NULL));
+
 #else
 	if(cvs_locale)
 		TRACE(3,"Platform does not have setlocale - locale override ignored");	
@@ -1164,7 +1179,11 @@ Copyright (c) 1989-2001 Brian Berliner, david d `zoo' zuhn, \n\
 	if(server_active)
 	{
 		struct sockaddr_storage ss = {0};
+#ifdef __hpux
+		int ss_len = (int)sizeof(ss);
+#else
 		socklen_t ss_len = sizeof(ss);
+#endif
 		int flags;
 
 		if(no_reverse_dns)
