@@ -23,8 +23,8 @@ static void rename_dbmfile (char *temp);
 static void write_dbmfile (char *temp);
 #endif				/* !MY_NDBM */
 
-/* Set to 1 to enable remote init commands */
-extern int remote_init;
+/* Set to a valid non_root directory to enable remote init commands */
+extern const char *remote_init_root;
 
 /* Structure which describes an administrative file.  */
 struct admin_file {
@@ -733,7 +733,7 @@ int mkmodules (char *dir)
 		;
 	    *cp = '\0';
 
-	    if(isabsolute(fname) || pathname_levels(fname)>0)
+	    if(isabsolute(fname) || pathname_levels(fname)>0 || !fncmp(fname,"checkoutlist"))
 		{
 			error(0,0,"Invalid filename '%s' in checkoutlist", fname);
 			continue;
@@ -1148,20 +1148,31 @@ int init (int argc, char **argv)
 
 	if(server_active)
 	{
-		if(!remote_init)
-			error(1,0,"Remote init commands have been disabled by the server administrator");
 		if(!verify_admin())
 			error(1,0,"Only repository administrators can run a remote cvs init command");
+		if(!remote_init_root)
+			error(1,0,"Remote init commands have been disabled by the server administrator");
+		if(!isabsolute(remote_init_root))
+			error(1,0,"Remote init root directory is not an absolute path - remote init disabled");
 		if(!root && !unregister)
 			error(1,0,"Must specify root for remote init command");
 
+		if(root && (root[0]!='/' || strstr(root,"..")))
+			error(1,0,"Root has incorrect format (unix style absolute path required)");
+
+		if(alias && alias[0]!='/')
+			error(1,0,"Alias has incorrect format (unix style absolute path required)");
 		if(root)
 		{
 			free_cvsroot_t(current_parsed_root);
 			current_parsed_root = new_cvsroot_t();
+			current_parsed_root->directory = (const char*)xmalloc(strlen(root)+strlen(remote_init_root)+10);
+			sprintf((char*)current_parsed_root->directory,"%s%s",remote_init_root,root);
 			current_parsed_root->original = xstrdup(alias?alias:root);
-			current_parsed_root->directory = xstrdup(root);
 			current_parsed_root->unparsed_directory = xstrdup(alias?alias:root);
+
+			Lock_Cleanup();
+			lock_register_client(CVS_Username,current_parsed_root->directory);
 		}
 		else if(alias)
 		{
@@ -1266,6 +1277,36 @@ int init (int argc, char **argv)
 		}
 	}
 
+	if(reg)
+	{
+		for(n=0; n<1000000; n++)
+		{
+			snprintf(tmp,sizeof(tmp),"Repository%d",n);
+			if(CGlobalSettings::GetGlobalValue("cvsnt","PServer",tmp,buffer,sizeof(buffer)))
+				break;
+		}
+		if(n==1000000)
+			error(1,0,"1000000 repositories?  Are you mad?");
+
+		if(CGlobalSettings::SetGlobalValue("cvsnt","PServer",tmp,current_parsed_root->directory))
+		{
+			error(0,0,"Unable to register repository.");
+			error(0,0,"Your login may not have sufficient permissions to modify the");
+			error(0,0,"global server settings.");
+			return 1;
+		}
+		else
+		{
+			snprintf(tmp,sizeof(tmp),"Repository%dName", n);
+			CGlobalSettings::SetGlobalValue("cvsnt","PServer",tmp,current_parsed_root->unparsed_directory);
+			if(description)
+			{
+				snprintf(tmp,sizeof(tmp),"Repository%dDescription", n);
+				CGlobalSettings::SetGlobalValue("cvsnt","PServer",tmp,description);
+			}
+		}
+	}
+
     /* Note: we do *not* create parent directories as needed like the
        old cvsinit.sh script did.  Few utilities do that, and a
        non-existent parent directory is as likely to be a typo as something
@@ -1402,35 +1443,6 @@ int init (int argc, char **argv)
 
     xfree (adm);
 
-	if(reg)
-	{
-		for(n=0; n<1000000; n++)
-		{
-			snprintf(tmp,sizeof(tmp),"Repository%d",n);
-			if(CGlobalSettings::GetGlobalValue("cvsnt","PServer",tmp,buffer,sizeof(buffer)))
-				break;
-		}
-		if(n==1000000)
-			error(1,0,"1000000 repositories?  Are you mad?");
-
-		if(CGlobalSettings::SetGlobalValue("cvsnt","PServer",tmp,current_parsed_root->directory))
-		{
-			error(0,0,"Unable to register repository.");
-			error(0,0,"Your login may not have sufficient permissions to modify the");
-			error(0,0,"global server settings.");
-		}
-		else
-		{
-			snprintf(tmp,sizeof(tmp),"Repository%dName", n);
-			CGlobalSettings::SetGlobalValue("cvsnt","PServer",tmp,current_parsed_root->unparsed_directory);
-			if(description)
-			{
-				snprintf(tmp,sizeof(tmp),"Repository%dDescription", n);
-				CGlobalSettings::SetGlobalValue("cvsnt","PServer",tmp,current_parsed_root->unparsed_directory);
-			}
-		}
-	}
-
 	if(alias)
 		error(0,0,"Repository %s (%s) initialised",alias,current_parsed_root->directory);
 	else
