@@ -130,6 +130,9 @@ int do_module (DBM *db, const char *mname, enum mtype m_type,  const char *msg,
     int nonalias_opt = 0;
 	char *strip_mname;
 
+	for(char *p=(char*)mname;*p;p++)
+		if(*p=='\\') *p='/';
+
 #ifdef SERVER_SUPPORT
     int restore_server_dir = 0;
     char *server_dir_to_restore = NULL;
