@@ -341,6 +341,7 @@ static int patch_fileproc (void *callerdat, struct file_info *finfo)
     char *cp1, *cp2;
     FILE *fp;
     int line_length;
+    char *nrev2;
 
     line1 = NULL;
     line1_chars_allocated = 0;
@@ -356,9 +357,19 @@ static int patch_fileproc (void *callerdat, struct file_info *finfo)
 
     rcs = (char*)xmalloc (strlen (finfo->file) + sizeof (RCSEXT) + 5);
     (void) sprintf (rcs, "%s%s", finfo->file, RCSEXT);
+ 
+    /* Keep 'on branch' so we don't diff against an arbitrary HEAD */
+    if(!rev2 && !date2)
+    {
+	nrev2 = RCS_branch_head(rcsfile, rev1);
+	if(!nrev2)
+		nrev2 = xstrdup(rev1);
+    }
+    else
+	nrev2=xstrdup(rev2);
 
     /* if vers_head is NULL, may have been removed from the release */
-	vers_head = RCS_getversion (rcsfile, rev2, date2, force_tag_match,
+	vers_head = RCS_getversion (rcsfile, nrev2, date2, force_tag_match,
 				    (int *) NULL);
 	if (vers_head != NULL && RCS_isdead (rcsfile, vers_head))
 	{
@@ -511,7 +522,7 @@ static int patch_fileproc (void *callerdat, struct file_info *finfo)
     if (vers_head != NULL)
     {
 	retcode = RCS_checkout (rcsfile, (char *) NULL, vers_head,
-				rev2, options, tmpfile2,
+				nrev2, options, tmpfile2,
 				(RCSCHECKOUTPROC) NULL, (void *) NULL, NULL);
 	if (retcode != 0)
 	{
@@ -684,12 +695,10 @@ failed to read diff file header %s for %s: end of file", tmpfile3, rcs);
     tmpfile1 = tmpfile2 = tmpfile3 = NULL;
 
  out2:
-    if (vers_tag != NULL)
-	xfree (vers_tag);
-    if (vers_head != NULL)
-	xfree (vers_head);
-    if (rcs != NULL)
-	xfree (rcs);
+    xfree(nrev2);
+    xfree (vers_tag);
+    xfree (vers_head);
+    xfree (rcs);
     return (ret);
 }
 
