@@ -243,15 +243,23 @@ int RCS_merge(RCSNode *rcs, const char *path, const char *workfile, const char *
 
 	TRACE(2,"rcs_merge(%s,%s,%s,%s,%s,%s)",PATCH_NULL(rcs->path),PATCH_NULL(path),PATCH_NULL(workfile),PATCH_NULL(options),PATCH_NULL(rev1),PATCH_NULL(rev2));
 
-    cvs_output ("RCS file: ", 0);
-    cvs_output (fn_root(rcs->path), 0);
-    cvs_output ("\n", 1);
-
     /* Calculate numeric revision numbers from rev1 and rev2 (may be
        symbolic). */
     xrev1 = RCS_gettag (rcs, rev1, 0, NULL);
     xrev2 = RCS_gettag (rcs, rev2, 0, NULL);
 
+	/* They are the same symbolic revision - do nothing */
+	if(!strcmp(xrev1,xrev2))
+	{
+		xfree(xrev1);
+		xfree(xrev2);
+		return 3; /* No difference */
+	}
+
+	cvs_output ("RCS file: ", 0);
+    cvs_output (fn_root(rcs->path), 0);
+    cvs_output ("\n", 1);
+
     /* Check out chosen revisions.  The error message when RCS_checkout
        fails is not very informative -- it is taken verbatim from RCS 5.7,
        and relies on RCS_checkout saying something intelligent upon failure. */
