@@ -13,7 +13,7 @@
 
 //#define DEBUG_MALLOC
 
-#if defined(_DEBUG) && defined(DEBUG_MALLOC)
+#if defined(_DEBUG) && defined(DEBUG_MALLOC) && defined(_WIN32)
 #define MALLOC_CHECK() if(!_CrtCheckMemory()) _asm int 3
 #else
 #define MALLOC_CHECK() do { } while(0);
@@ -822,13 +822,18 @@ void get_file (const char *name, const char *fullname, const char *mode,
 		CCodepage cdp;
 		void *newbuf = NULL;
 		size_t newsize;
+		int res;
 		cdp.BeginEncoding(kf.encoding,CCodepage::Utf8Encoding);
-		if(cdp.ConvertEncoding(*buf,nread,newbuf, newsize))
+		if((res=cdp.ConvertEncoding(*buf,nread,newbuf, newsize))>0)
 		{
 			xfree(*buf);
 			*buf = (char *)newbuf;
 			nread = *bufsize = newsize;
 		}
+		else if(res<0)
+		{
+			error(0,0,"Unable to convert from %s to UTF-8",kf.encoding.encoding);
+		}
 		cdp.EndEncoding();
 		cdp.StripCrLf(*buf,nread);
 	}
