@@ -454,7 +454,7 @@ static int check_fileproc (void *callerdat, struct file_info *finfo)
     if (check_uptodate) 
     {
 		Ctype status = Classify_File (finfo, (char *) NULL, (char *) NULL,
-						(char *) NULL, 1, 0, &vers, 0, 0);
+						(char *) NULL, 1, 0, &vers, 0, 0, 0);
 
 		if ((status != T_UPTODATE) && (status != T_CHECKOUT) &&
 			(status != T_PATCH) && (status != T_REMOVE_ENTRY))
