@@ -634,7 +634,7 @@ static int update_fileproc (void *callerdat, struct file_info *finfo)
 	file_is_edited = 0;
 
     status = Classify_File (finfo, tag, date, options, force_tag_match,
-			    aflag, &vers, pipeout, 0);
+			    aflag, &vers, pipeout, 0, 0);
 
     /* Keep track of whether TAG is a branch tag.
        Note that if it is a branch tag in some files and a nonbranch tag
@@ -2601,30 +2601,23 @@ static void join_file (struct file_info *finfo, Vers_TS *vers)
 		{
 			char *rev_tmp = gca (vers->vn_rcs, rev2);
 			char *branchpoint = branchpoint_of(vers->srcfile, vers->tag);
-//			char *target_branchpoint = branchpoint_of(vers->srcfile, jrev2);
 
 			//TH: removed bidirectional mergepoint handling,
 			//since it doesn't make logical sense (A->B != B->A)
 
 			/* Special case if we're at the branchpoint and/or there are no revisions on the branch */
-			if(merge_from_branchpoint || (branchpoint && !strcmp(vers->vn_rcs, branchpoint)) /*|| (target_branchpoint && !strcmp(rev2, target_branchpoint))*/)
+			if(merge_from_branchpoint || (rev_tmp && !strcmp(rev2,rev_tmp)) || (branchpoint && !strcmp(vers->vn_rcs, branchpoint)))
 			{
 				rev1 = rev_tmp;
 				xfree(branchpoint);
-//				xfree(target_branchpoint);
 			}
 			else
 			{
 				/* We found the branchpoint, now find the highest mergepoint with this prefix */
-//				char *rev1_tmp;
 				rev1 = getmergepoint(vers->srcfile, rev_tmp, vers->vn_rcs, rev2);
 				TRACE(3,"getmergepoint(%s, %s, %s)=%s",PATCH_NULL(rev_tmp),PATCH_NULL(vers->vn_rcs),PATCH_NULL(rev2),PATCH_NULL(rev1));
-//				rev1 = getmergepoint(vers->srcfile, rev1_tmp, rev2, vers->vn_rcs);
-//				TRACE(3,"getmergepoint(%s, %s, %s)=%s", PATCH_NULL(rev1_tmp),PATCH_NULL(rev2),PATCH_NULL(vers->vn_rcs),PATCH_NULL(rev1));
-//				xfree(rev1_tmp);
 				xfree(rev_tmp);
 				xfree(branchpoint);
-//				xfree(target_branchpoint);
 			}
 		}
     }
