@@ -688,7 +688,7 @@ static int xdiff_exec (const char *name, const char *file1, const char *file2, c
 		if(line.size())
 		{
 			CLibraryAccess lib;
-			if(!lib.Load(line[0],CGlobalSettings::GetLibraryDirectory()))
+			if(!lib.Load(line[0],CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDXdiff)))
 				error(1,0,"Cannot load xdiff handler for %s",name);
 
 			get_plugin_interface_t fn = (get_plugin_interface_t)lib.GetProc("get_plugin_interface");
