@@ -13,7 +13,7 @@ def usage():
   
 def cvs(command):
   #cmd = 'valgrind -q --logfile-fd=9 cvs --allow-root='+base_dir+'/repos,/repos -d'+current_cvsroot+' '+command+' >'+outfile+' 2>'+errfile+' 9>/dev/stderr'
-  cmd = 'cvs --allow-root="'+base_dir+'/repos",/repos -d'+current_cvsroot+' '+command+' >"'+outfile+'" 2>"'+errfile+'"'
+  cmd = 'cvs --allow-root="'+current_physroot+','+current_cvsroot+'" -d'+current_cvsroot+' '+command+' >"'+outfile+'" 2>"'+errfile+'"'
   if(verbose): print cmd
   result = os.system(cmd)
 #  if(verbose):
@@ -75,80 +75,84 @@ def file_delete(filename):
   os.unlink(filename)
 
 def main():
-  global verbose, atomic, base_dir, current_cvsroot, outfile, errfile
+  global verbose, atomic, base_dir, current_cvsroot, current_physroot, outfile, errfile
   try:
-    opts, args = getopt.getopt(sys.argv[1:], "va", ["verbose", "atomic"])
+    opts, args = getopt.getopt(sys.argv[1:], "vai:", ["verbose", "atomic"])
   except getopt.GetoptError:
     usage()
     sys.exit(2)
   verbose = 0
   atomic = 0
+  instance = '0'
   for o,a in opts:
     if o in ("-v", "--verbose"):
       verbose = 1
     if o in ("-a", "--atomic"):
       atomic = 1
+    if o in ("-i", "--instance"):
+       instance = a
 
   base_dir = os.getcwd()
-  outfile = base_dir+'/testcvs.out'
-  errfile = base_dir+'/testcvs.err'
+  outfile = base_dir+'/testcvs_'+instance+'.out'
+  errfile = base_dir+'/testcvs_'+instance+'.err'
   current_cvsroot = '/repos'
-  current_tree = base_dir+'/tree'
+  current_physroot = base_dir+current_cvsroot+'_'+instance
+  current_tree = base_dir+'/tree_'+instance
   current_test = '(none)'
   test_data = base_dir+'/test_data'
   try:
-    shutil.rmtree(base_dir+current_cvsroot,1) 
+    shutil.rmtree(current_tree) 
   except OSError:
     0
   try:
-    shutil.rmtree(current_tree,1) 
+    shutil.rmtree(current_physroot) 
   except OSError:
     0
-  os.mkdir(base_dir+current_cvsroot)
+  os.mkdir(current_physroot)
   os.mkdir(current_tree)
 
   start_test('Basic functionality, Init, Import, Checkout')
   cvs_pass('-v')
   cvs_fail('version')
   cvs_pass('init -n')
-  dir_exists(base_dir+current_cvsroot+'/CVSROOT')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/checkoutlist')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/checkoutlist,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/commitinfo')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/commitinfo,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/config')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/config,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/cvswrappers')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/cvswrappers,v')
-#  file_exists(base_dir+current_cvsroot+'/CVSROOT/history')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/loginfo')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/loginfo,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/modules')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/modules,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/notify')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/notify,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/rcsinfo')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/rcsinfo,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/taginfo')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/taginfo,v')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/verifymsg')
-  file_exists(base_dir+current_cvsroot+'/CVSROOT/verifymsg,v')
+  dir_exists(current_physroot+'/CVSROOT')
+  file_exists(current_physroot+'/CVSROOT/checkoutlist')
+  file_exists(current_physroot+'/CVSROOT/checkoutlist,v')
+  file_exists(current_physroot+'/CVSROOT/commitinfo')
+  file_exists(current_physroot+'/CVSROOT/commitinfo,v')
+  file_exists(current_physroot+'/CVSROOT/config')
+  file_exists(current_physroot+'/CVSROOT/config,v')
+  file_exists(current_physroot+'/CVSROOT/cvswrappers')
+  file_exists(current_physroot+'/CVSROOT/cvswrappers,v')
+#  file_exists(current_physroot+'/CVSROOT/history')
+  file_exists(current_physroot+'/CVSROOT/loginfo')
+  file_exists(current_physroot+'/CVSROOT/loginfo,v')
+  file_exists(current_physroot+'/CVSROOT/modules')
+  file_exists(current_physroot+'/CVSROOT/modules,v')
+  file_exists(current_physroot+'/CVSROOT/notify')
+  file_exists(current_physroot+'/CVSROOT/notify,v')
+  file_exists(current_physroot+'/CVSROOT/rcsinfo')
+  file_exists(current_physroot+'/CVSROOT/rcsinfo,v')
+  file_exists(current_physroot+'/CVSROOT/taginfo')
+  file_exists(current_physroot+'/CVSROOT/taginfo,v')
+  file_exists(current_physroot+'/CVSROOT/verifymsg')
+  file_exists(current_physroot+'/CVSROOT/verifymsg,v')
   # This should probably do the whole checkout/commit of cvsroot thing.
   if atomic:
     print 'Switching to atomic mode...'
-    os.chmod(base_dir+current_cvsroot+'/CVSROOT/config',0644)
-    file_copy(test_data + '/atomic_config', base_dir+current_cvsroot+'/CVSROOT/config')
+    os.chmod(current_physroot+'/CVSROOT/config',0644)
+    file_copy(test_data + '/atomic_config', current_physroot+'/CVSROOT/config')
   os.chdir(test_data + '/import_test')
   cvs_pass('import -m "Initial import" testcvs test1 test2')
-  dir_exists(base_dir+current_cvsroot+'/testcvs')
-  dir_exists(base_dir+current_cvsroot+'/testcvs/sub')
-  dir_exists(base_dir+current_cvsroot+'/testcvs/sub2')
-  file_exists(base_dir+current_cvsroot+'/testcvs/test1.txt,v')
-  file_exists(base_dir+current_cvsroot+'/testcvs/test2.txt,v')
-  file_exists(base_dir+current_cvsroot+'/testcvs/sub/test3.txt,v')
-  file_exists(base_dir+current_cvsroot+'/testcvs/sub/test4.txt,v')
-  file_exists(base_dir+current_cvsroot+'/testcvs/sub2/test5.txt,v')
-  file_exists(base_dir+current_cvsroot+'/testcvs/sub2/test6.txt,v') 
+  dir_exists(current_physroot+'/testcvs')
+  dir_exists(current_physroot+'/testcvs/sub')
+  dir_exists(current_physroot+'/testcvs/sub2')
+  file_exists(current_physroot+'/testcvs/test1.txt,v')
+  file_exists(current_physroot+'/testcvs/test2.txt,v')
+  file_exists(current_physroot+'/testcvs/sub/test3.txt,v')
+  file_exists(current_physroot+'/testcvs/sub/test4.txt,v')
+  file_exists(current_physroot+'/testcvs/sub2/test5.txt,v')
+  file_exists(current_physroot+'/testcvs/sub2/test6.txt,v') 
   cvs_pass('version')
   os.chdir(current_tree)
   cvs_fail('co cvsfailtest')
@@ -170,43 +174,72 @@ def main():
   file_compare(test_data+'/import_test/sub2/test5.txt',current_tree+'/testcvs/sub2/test5.txt')
   file_compare(test_data+'/import_test/sub2/test6.txt',current_tree+'/testcvs/sub2/test6.txt')
 
+###
+#  os.chdir(current_tree+'/testcvs')
+#  fname = 'test1.txt'
+#  module = 'testcvs'
+#  for fcnt in range(20000):
+#    cvs_pass('ci -m change1 '+fname)
+#    cvs_pass('-z7 log '+fname)
+#    cvs_pass('stat '+fname)
+#    cvs_pass('-z7 up '+fname)
+#    cvs_pass('diff -r1 '+fname)
+#    cvs_pass('tag -F aa'+str(fcnt)+' '+fname)
+#    cvs_pass('stat -v '+fname)
+#    cvs_pass('editors '+fname)
+##    cvs_pass('history '+fname)
+#    cvs_pass('watchers '+fname)
+#    file_copy(test_data+'/diff_test.txt.2',current_tree+'/testcvs/'+fname)
+#    cvs_pass('ci -m change2 '+fname)
+#    cvs_pass('-z6 diff -r1 '+fname)
+#    cvs_pass('rtag -b branch_'+str(fcnt)+' '+module)
+#    cvs_pass('rlog '+module)
+#    file_copy(test_data+'/maastrict.txt',current_tree+'/testcvs/'+fname)
+#    cvs_pass('-z7 ci -m grow '+fname)
+#    os.unlink(fname)
+#    cvs_pass('up '+fname)
+#    file_copy(test_data+'/add_test.txt',current_tree+'/testcvs/'+fname)
+#    cvs_pass('ci -m shrink '+fname)
+#  exit(1)
+###
+
   start_test('Basic Add, Remove, Resurrect, Commit')
 
   os.chdir(current_tree+'/testcvs')
   file_copy(test_data+'/add_test.txt','add_test.txt')
   cvs_pass('add add_test.txt')
   file_exists(current_tree+'/testcvs/add_test.txt')
-  file_not_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
+  file_not_exists(current_physroot+'/testcvs/add_test.txt,v')
   cvs_pass('commit -m "" add_test.txt')
   file_exists(current_tree+'/testcvs/add_test.txt')
-  file_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
+  file_exists(current_physroot+'/testcvs/add_test.txt,v')
   cvs_pass('remove -f add_test.txt')
   file_not_exists(current_tree+'/testcvs/add_test.txt')
-  file_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
+  file_exists(current_physroot+'/testcvs/add_test.txt,v')
   cvs_pass('add add_test.txt')
   file_exists(current_tree+'/testcvs/add_test.txt')
-  file_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
+  file_exists(current_physroot+'/testcvs/add_test.txt,v')
   cvs_pass('commit -m "" add_test.txt')
   cvs_pass('remove -f add_test.txt')
   file_not_exists(current_tree+'/testcvs/add_test.txt')
-  file_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
+  file_exists(current_physroot+'/testcvs/add_test.txt,v')
   cvs_pass('commit -m "" add_test.txt')
   file_not_exists(current_tree+'/testcvs/add_test.txt')
-#  file_not_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
-#  dir_exists(base_dir+current_cvsroot+'/testcvs/Attic')
-#  file_exists(base_dir+current_cvsroot+'/testcvs/Attic/add_test.txt,v')
+#  file_not_exists(current_physroot+'/testcvs/add_test.txt,v')
+#  dir_exists(current_physroot+'/testcvs/Attic')
+#  file_exists(current_physroot+'/testcvs/Attic/add_test.txt,v')
   file_copy(test_data+'/add_test.txt','add_test.txt')
   cvs_pass('add add_test.txt')
   cvs_pass('commit -m "" add_test.txt')
   file_exists(current_tree+'/testcvs/add_test.txt')
-  file_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
+  file_exists(current_physroot+'/testcvs/add_test.txt,v')
   cvs_pass('remove -f add_test.txt')
   file_not_exists(current_tree+'/testcvs/add_test.txt')
   cvs_pass('commit -m "" add_test.txt')
   file_not_exists(current_tree+'/testcvs/add_test.txt')
-#  file_not_exists(base_dir+current_cvsroot+'/testcvs/add_test.txt,v')
-#  dir_exists(base_dir+current_cvsroot+'/testcvs/Attic')
-#  file_exists(base_dir+current_cvsroot+'/testcvs/Attic/add_test.txt,v')
+#  file_not_exists(current_physroot+'/testcvs/add_test.txt,v')
+#  dir_exists(current_physroot+'/testcvs/Attic')
+#  file_exists(current_physroot+'/testcvs/Attic/add_test.txt,v')
   cvs_pass('remove -f add_test.txt') # Should fail IMHO but standard cvs doesn't
   cvs_fail('commit -m "" fail_test.txt')
 
@@ -217,7 +250,7 @@ def main():
   cvs_pass('add -kb binary_test.gif')
   cvs_pass('commit -m "" binary_test.gif')
   file_exists(current_tree+'/testcvs/binary_test.gif')
-  file_exists(base_dir+current_cvsroot+'/testcvs/binary_test.gif,v')
+  file_exists(current_physroot+'/testcvs/binary_test.gif,v')
   file_compare(test_data+'/binary_test.gif',current_tree+'/testcvs/binary_test.gif')
   file_delete(current_tree+'/testcvs/binary_test.gif')
   cvs_pass('update binary_test.gif')
@@ -243,7 +276,7 @@ def main():
   cvs_pass('add -kB binary_delta_test.gif')
   cvs_pass('commit -m "" binary_delta_test.gif')
   file_exists(current_tree+'/testcvs/binary_delta_test.gif')
-  file_exists(base_dir+current_cvsroot+'/testcvs/binary_delta_test.gif,v')
+  file_exists(current_physroot+'/testcvs/binary_delta_test.gif,v')
   file_compare(test_data+'/binary_test.gif',current_tree+'/testcvs/binary_delta_test.gif')
   file_delete(current_tree+'/testcvs/binary_delta_test.gif')
   cvs_pass('update binary_delta_test.gif')
@@ -255,7 +288,7 @@ def main():
   cvs_pass('add maastrict.txt')
   cvs_pass('commit -m "" maastrict.txt')
   file_exists(current_tree+'/testcvs/maastrict.txt')
-  file_exists(base_dir+current_cvsroot+'/testcvs/maastrict.txt,v')
+  file_exists(current_physroot+'/testcvs/maastrict.txt,v')
   file_compare(test_data+'/maastrict.txt',current_tree+'/testcvs/maastrict.txt')
   file_delete(current_tree+'/testcvs/maastrict.txt')
   cvs_pass('update maastrict.txt')
@@ -412,12 +445,12 @@ def main():
 
   start_test('*info')
 
-  os.chmod(base_dir+current_cvsroot+'/CVSROOT/commitinfo',0644)
-  os.chmod(base_dir+current_cvsroot+'/CVSROOT/loginfo',0644)
-  os.chmod(base_dir+current_cvsroot+'/CVSROOT/postcommand',0644)
-  file_copy(test_data + '/commitinfo_test', base_dir+current_cvsroot+'/CVSROOT/commitinfo')
-  file_copy(test_data + '/loginfo_test', base_dir+current_cvsroot+'/CVSROOT/loginfo')
-  file_copy(test_data + '/postcommand_test', base_dir+current_cvsroot+'/CVSROOT/postcommand')
+  os.chmod(current_physroot+'/CVSROOT/commitinfo',0644)
+  os.chmod(current_physroot+'/CVSROOT/loginfo',0644)
+  os.chmod(current_physroot+'/CVSROOT/postcommand',0644)
+  file_copy(test_data + '/commitinfo_test', current_physroot+'/CVSROOT/commitinfo')
+  file_copy(test_data + '/loginfo_test', current_physroot+'/CVSROOT/loginfo')
+  file_copy(test_data + '/postcommand_test', current_physroot+'/CVSROOT/postcommand')
   cvs_pass('commit -f -m "info test" diff_test.txt')
   if os.name == 'nt':
     file_compare(outfile, test_data+'/info_test_output.txt')
