@@ -7,6 +7,8 @@ function copy_headers {
 rm -rf "${TARGET}/pdb"
 rm -rf "${TARGET}/inc"
 rm -rf "${TARGET}/lib"
+rm -rf "${TARGET}/protocols"
+rm -rf "${TARGET}/triggers"
 mkdir "${TARGET}/inc"
 mkdir "${TARGET}/inc/win32"
 mkdir "${TARGET}/inc/unix"
@@ -15,10 +17,19 @@ mkdir "${TARGET}/inc/diff"
 mkdir "${TARGET}/inc/apiloader"
 mkdir "${TARGET}/lib"
 mkdir "${TARGET}/pdb"
+mkdir "${TARGET}/pdb/triggers"
+mkdir "${TARGET}/pdb/protocols"
+mkdir "${TARGET}/pdb/xdiff"
+mkdir "${TARGET}/triggers"
+mkdir "${TARGET}/protocols"
+mkdir "${TARGET}/xdiff"
 cd "${BASE}"
 cp ${TYPE}/*.exe "${TARGET}"
 cp ${TYPE}/*.dll "${TARGET}"
 cp ${TYPE}/*.cpl "${TARGET}"
+cp ${TYPE}/triggers/*.dll "${TARGET}/triggers"
+cp ${TYPE}/protocols/*.dll "${TARGET}/protocols"
+cp ${TYPE}/xdiff/*.dll "${TARGET}/xdiff"
 cp ${TYPE}/setuid.dll "${SYSTEMROOT}/system32"
 cp ${TYPE}/setuid.dll "${SYSTEMROOT}/system32/setuid2.dll"
 cp ${TYPE}/apiloader.lib "${TARGET}/lib"
@@ -39,7 +50,7 @@ cp cvstools/cvstools.h "${TARGET}/inc"
 copy_headers cvstools/win32 inc/win32
 # copy_headers cvstools/unix inc/unix
 copy_headers cvstools inc
-# copy_headers cvsapi/win32 inc/win32
+copy_headers cvsapi/win32 inc/win32
 # copy_headers cvsapi/unix inc/unix
 copy_headers cvsapi/lib inc/lib
 copy_headers cvsapi/diff inc/diff
