@@ -33,15 +33,18 @@ build-pdk.bat $BUILD
 cd "$TOP"
 cp cvsnt/doc/*.chm ..
 cp cvsnt/WinRel/*.pdb ../pdb
+cp cvsnt/WinRel/protocols/*.pdb ../pdb/protocols
+cp cvsnt/WinRel/triggers/*.pdb ../pdb/triggers
+cp cvsnt/WinRel/xdiff/*.pdb ../pdb/xdiff
 cd cvsnt/installer
 nmake
 mv cvsnt-${BUILD}.msi ../../..
 makeu3.bat ${BUILD}
 mv cvsagent-${BUILD}.u3p ../../..
 cd ../../..
-wzzip cvsnt-${BUILD}-bin.zip *.dll *.exe *.cpl *.ini ca.pem infolib.h COPYING
-wzzip cvsnt-${BUILD}-pdb.zip pdb
-wzzip -P cvsnt-${BUILD}-dev.zip cvsnt-pdk.chm inc lib
+wzzip -P cvsnt-${BUILD}-bin.zip *.dll *.exe *.cpl *.ini ca.pem infolib.h COPYING triggers protocols xdiff
+wzzip -pr cvsnt-${BUILD}-pdb.zip pdb
+wzzip -Pr cvsnt-${BUILD}-dev.zip cvsnt-pdk.chm inc lib
 cp keep/*.* .
 echo ${BUILD} >release
 pscp -i d:/tony.ppk *.zip cvsnt-${BUILD}.msi *.u3p cvs.chm release tmh@sisko:/home/tmh/cvs
