@@ -33,7 +33,7 @@
 #include <unistd.h>
 #endif
 
-#define MODULE audit_trigger
+#define MODULE audit
 
 #include <ctype.h>
 #include <cvstools.h>
@@ -81,22 +81,22 @@ static CSqlConnection* Connect(int nType, const char *name, const char *host, co
 	switch(nType)
 	{
 	case 0:
-		pDb = CSqlConnection::Alloc(sqtMysql,CGlobalSettings::GetLibraryDirectory());
+		pDb = CSqlConnection::Alloc(sqtMysql,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDDatabase));
 		break;
 	case 1:
-		pDb = CSqlConnection::Alloc(sqtSqlite,CGlobalSettings::GetLibraryDirectory());
+		pDb = CSqlConnection::Alloc(sqtSqlite,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDDatabase));
 		break;
 	case 2:
-		pDb = CSqlConnection::Alloc(sqtPostgres,CGlobalSettings::GetLibraryDirectory());
+		pDb = CSqlConnection::Alloc(sqtPostgres,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDDatabase));
 		break;
 	case 3:
-		pDb = CSqlConnection::Alloc(sqtOdbc,CGlobalSettings::GetLibraryDirectory());
+		pDb = CSqlConnection::Alloc(sqtOdbc,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDDatabase));
 		break;
 	case 4:
-		pDb = CSqlConnection::Alloc(sqtMssql,CGlobalSettings::GetLibraryDirectory());
+		pDb = CSqlConnection::Alloc(sqtMssql,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDDatabase));
 		break;
 	case 5:
-		pDb = CSqlConnection::Alloc(sqtDb2,CGlobalSettings::GetLibraryDirectory());
+		pDb = CSqlConnection::Alloc(sqtDb2,CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDDatabase));
 		break;
 	default:
 		pDb = NULL;
@@ -432,9 +432,9 @@ BOOL CALLBACK ConfigDlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
 	switch(uMsg)
 	{
 	case WM_INITDIALOG:
-		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"MySql");
+		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"MySQL");
 		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"SQLite");
-		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"Postresql");
+		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"PostgreSQL");
 		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"Generic ODBC");
 		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"SQL Server / MSDE");
 		SendDlgItemMessage(hWnd,IDC_COMBO1,CB_ADDSTRING,NULL,(LPARAM)L"IBM DB2");
@@ -604,7 +604,7 @@ BOOL CALLBACK ConfigDlgProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
 				wchar_t name[256],prefix[256],user[256],password[256],host[256];
 				cvs::string error;
 
-				fn = CGlobalSettings::GetLibraryDirectory();
+				fn = CGlobalSettings::GetLibraryDirectory(CGlobalSettings::GLDLib);
 				fn+="/sql/create_tables_";
 
 				nSel = SendDlgItemMessage(hWnd,IDC_COMBO1,CB_GETCURSEL,NULL,NULL);
