@@ -42,7 +42,7 @@
 #include <unistd.h>
 #endif
 
-#define MODULE checkout_trigger
+#define MODULE checkout
 
 #include <ctype.h>
 #include <cvstools.h>
@@ -192,6 +192,7 @@ int postcommand(const struct trigger_interface_t* cb, const char *directory)
 			p++;
 		if(*p=='#')
 			continue;
+
 		CTokenLine tok(p);
 
 		if(tok.size()!=3)
@@ -203,8 +204,11 @@ int postcommand(const struct trigger_interface_t* cb, const char *directory)
 		bool found = false;
 		for(std::map<cvs::filename,int>::const_iterator i = module_list.begin(); i!=module_list.end(); ++i)
 		{
-			if(!fnncmp(i->first.c_str(),tok[0],strlen(tok[0])))
+			CServerIo::trace(3,"Regexp match: %s - %s",tok[0],i->first.c_str());
+			cvs::wildcard_filename mod(i->first.c_str());
+			if(mod.matches_regexp(tok[0])) // Wildcard match
 			{
+				CServerIo::trace(3,"Match found!");
 				found=true;
 				break;
 			}
