@@ -27,6 +27,7 @@
 #ifdef _WIN32
 #include <process.h>
 #include <winsock2.h>
+#include <ws2tcpip.h>
 #include <mapi.h>
 #endif
 #ifdef HAVE_SYS_TYPES_H
@@ -42,7 +43,7 @@
 #include <unistd.h>
 #endif
 
-#define MODULE email_trigger
+#define MODULE email
 
 #include <ctype.h>
 #include <cvstools.h>
@@ -69,7 +70,7 @@ int win32config(const struct plugin_interface *ui, void *wnd);
 #endif
 
 
-bool parse_emailinfo(const char *file, const char *directory, cvs::string& emailfile);
+bool parse_emailinfo(const char *file, const char *directory, cvs::string& emailfile, bool& cache_valid, std::vector<cvs::string>& cache);
 const char *map_username(const char *user);
 bool start_mail(const char *from, const std::vector<cvs::string>& to);
 bool send_mail_line(const char *line);
@@ -198,7 +199,11 @@ int close(const struct trigger_interface_t* cb)
 int pretag(const struct trigger_interface_t* cb, const char *message, const char *directory, int name_list_count, const char **name_list, const char **version_list, char tag_type, const char *action, const char *tag)
 {
 	cvs::string file,tmp;
-	if(!parse_emailinfo(CVSROOT_TAGINFO,directory,file))
+
+	static bool cache_valid = false;
+	static std::vector<cvs::string> cache;
+
+	if(!parse_emailinfo(CVSROOT_TAGINFO,directory,file,cache_valid,cache))
 		return 0;
 
 	if(CFileAccess::absolute(file.c_str()) || CFileAccess::uplevel(file.c_str())>0)
@@ -239,7 +244,10 @@ int verifymsg(const struct trigger_interface_t* cb, const char *directory, const
 int loginfo(const struct trigger_interface_t* cb, const char *message, const char *status, const char *directory, int change_list_count, change_info_t *change_list)
 {
 	cvs::string file,tmp;
-	if(!parse_emailinfo(CVSROOT_LOGINFO,directory,file))
+	static bool cache_valid = false;
+	static std::vector<cvs::string> cache;
+
+	if(!parse_emailinfo(CVSROOT_LOGINFO,directory,file,cache_valid,cache))
 		return 0;
 
 	last_module = directory;
@@ -283,7 +291,10 @@ int history(const struct trigger_interface_t* cb, char type, const char *workdir
 int notify(const struct trigger_interface_t* cb, const char *message, const char *bugid, const char *directory, const char *notify_user, const char *tag, const char *type, const char *file)
 {
 	cvs::string nfile,tmp;
-	if(!parse_emailinfo(CVSROOT_NOTIFY,directory,nfile))
+	static bool cache_valid = false;
+	static std::vector<cvs::string> cache;
+
+	if(!parse_emailinfo(CVSROOT_NOTIFY,directory,nfile,cache_valid,cache))
 		return 0;
 
 	if(CFileAccess::absolute(nfile.c_str()) || CFileAccess::uplevel(nfile.c_str())>0)
@@ -302,7 +313,13 @@ int notify(const struct trigger_interface_t* cb, const char *message, const char
 	notify_change_list_t& change = notify_data[nfile.c_str()][notify_user][directory];
 	size_t n = change.size();
 	change.resize(n+1);
+	change[n].bugid=bugid;
+	change[n].filename=file;
+	change[n].tag=tag;
+	change[n].type=type;
 	loginfo_message = message?message:"";
+
+	CServerIo::trace(3,"Notify array modified, size=%d, count=%d",notify_data.size(),change.size());
 	return 0;
 }
 
@@ -636,19 +653,25 @@ int postcommand(const struct trigger_interface_t* cb, const char *directory)
 			std::vector<cvs::string> cache;
 			cvs::string from;
 			std::vector<cvs::string> to;
+			cvs::string user = map_username(j->first.c_str());
 			if(read_template(i->first.c_str(),cache, from, to))
 			{
 				size_t dir_repeat = 0;
 				size_t file_repeat = 0;
 				notify_change_list_t::const_iterator file_iterator;
 				notify_dir_list_t::const_iterator directory_iterator;
+				for(size_t n=0; n<to.size(); n++)
+				{
+					if(!strcmp(to[n].c_str(),"[to_user]"))
+					    to[n]=user;
+				}
 				start_mail(from.c_str(),to);
 				for(size_t n=0; n<cache.size(); n++)
 				{
 					cvs::string& line = cache[n]; 
 
 					while((pos=line.find("[to_user]"))!=cvs::string::npos)
-						line.replace(pos,10,map_username(j->first.c_str()));
+						line.replace(pos,10,user);
 
 					// repeating
 					if(line=="[begin_directory]")
@@ -708,6 +731,8 @@ int postcommand(const struct trigger_interface_t* cb, const char *directory)
 				}
 				end_mail();
 			}
+			else
+				CServerIo::trace(3,"read_template() failed");
 		}
 	}
 
@@ -807,7 +832,7 @@ plugin_interface *get_plugin_interface()
 	return &callbacks.plugin;
 }
 
-bool parse_emailinfo(const char *file, const char *directory, cvs::string& emailfile)
+bool parse_emailinfo(const char *file, const char *directory, cvs::string& emailfile, bool& cache_valid, std::vector<cvs::string>& cache)
 {
 	size_t current_line, default_current_line;
 	cvs::string str,default_line,here_text;
@@ -815,9 +840,6 @@ bool parse_emailinfo(const char *file, const char *directory, cvs::string& email
 	cvs::sprintf(str,512,"%s/%s",gen_info.physical_repository,file);
 	bool found = false;
 
-	static bool cache_valid = false;
-	static std::vector<cvs::string> cache;
-
 	CServerIo::trace(3,"email_trigger: parse_emailinfo(%s,%s)",file,directory?directory:"<null>");
 
 	if(!cache_valid)
@@ -861,20 +883,26 @@ bool parse_emailinfo(const char *file, const char *directory, cvs::string& email
 		if(mod.matches_regexp(tok[0])) // Wildcard match
 		{
 			found=true;
-			CServerIo::trace(3,"Match found!");
+			CServerIo::trace(3,"Match found");
 			emailfile=trailer;
 		}
 		else if(!strcmp(tok[0],"DEFAULT"))
 		{
+			CServerIo::trace(3,"Default found");
 			default_current_line = current_line;
 			default_line=trailer;
 		}
+		else
+			CServerIo::trace(3,"No match");
 	}
 	if(!found && default_line.size())
 	{
+		CServerIo::trace(3,"using default line");
 		emailfile=default_line;
 		found = true;
 	}
+	if(!found)
+		CServerIo::trace(3,"No match on any lines");
 
 	return found;
 }
@@ -1040,13 +1068,13 @@ bool CSmtpMailIo::start_mail(const char *from, const std::vector<cvs::string>& t
 		return false;
 	if(strchr(from,'@') || !emaildomain[0])
 	{
-		CServerIo::trace(3,"SMTP C: MAIL FROM: %s",from);
-		m_sock.printf("MAIL FROM: %s\r\n",from);
+		CServerIo::trace(3,"SMTP C: MAIL FROM:<%s>",from);
+		m_sock.printf("MAIL FROM:<%s>\r\n",from);
 	}
 	else
 	{
-		CServerIo::trace(3,"SMTP C: MAIL FROM: %s@%s",from,emaildomain);
-		m_sock.printf("MAIL FROM: %s@%s\r\n",from,emaildomain);
+		CServerIo::trace(3,"SMTP C: MAIL FROM:<%s@%s>",from,emaildomain);
+		m_sock.printf("MAIL FROM:<%s@%s>\r\n",from,emaildomain);
 	}
 	if(!get_smtp_response(m_sock))
 		return false;
@@ -1054,13 +1082,13 @@ bool CSmtpMailIo::start_mail(const char *from, const std::vector<cvs::string>& t
 	{
 		if(strchr(to[n].c_str(),'@') || !emaildomain[0])
 		{
-			CServerIo::trace(3,"SMTP C: RCPT TO: %s",to[n].c_str());
-			m_sock.printf("RCPT TO: %s\r\n",to[n].c_str());
+			CServerIo::trace(3,"SMTP C: RCPT TO:<%s>",to[n].c_str());
+			m_sock.printf("RCPT TO:<%s>\r\n",to[n].c_str());
 		}
 		else
 		{
-			CServerIo::trace(3,"SMTP C: RCPT TO: %s@%s",to[n].c_str(),emaildomain);
-			m_sock.printf("RCPT TO: %s@%s\r\n",to[n].c_str(),emaildomain);
+			CServerIo::trace(3,"SMTP C: RCPT TO:<%s@%s>",to[n].c_str(),emaildomain);
+			m_sock.printf("RCPT TO:<s@%s>\r\n",to[n].c_str(),emaildomain);
 		}
 		if(!get_smtp_response(m_sock))
 			return false;
