@@ -37,7 +37,7 @@
 #include <unistd.h>
 #endif
 
-#define MODULE default_trigger
+#define MODULE info
 
 #include <ctype.h>
 #include <cvstools.h>
@@ -1017,7 +1017,13 @@ int parse_info(const char *file, const char *default_cmd_parms, const char *defa
 			add=true;
 			tk++;
 		}
-		if(!strcmp(tok[0],"ALL") || ((!found || add) && mod.matches_regexp(tk))) // Wildcard match
+		if(strcmp(tok[0],"ALL")==0)
+		{
+			CServerIo::trace(3, "ALL found");
+			ret += parse_info_line(cache,trailer,generic_options,spec_options,file,current_line);
+			here_text="";
+		}
+		else if((!found || add) && mod.matches_regexp(tk)) // Wildcard match
 		{
 			CServerIo::trace(3,"Match found!");
 			ret += parse_info_line(cache,trailer,generic_options,spec_options,file,current_line);
