@@ -35,7 +35,7 @@
 #include <winsock2.h>
 #include <ctype.h>
 
-#define MODULE script_trigger
+#define MODULE script
 
 #include <map>
 #include <cvstools.h>
