@@ -1,6 +1,6 @@
 -- MySql specific configuration script
 
-Create Table SessionLog (Id Integer Auto_Increment Primary Key Not Null,
+Create Table %PREFIX%SessionLog (Id Integer Auto_Increment Primary Key Not Null,
 	Command varchar(32),
 	Date datetime,
 	Hostname varchar(255),
@@ -10,7 +10,7 @@ Create Table SessionLog (Id Integer Auto_Increment Primary Key Not Null,
 	PhysRepos varchar(255),
 	Client varchar(64));
 
-Create Table CommitLog (Id Integer Auto_Increment Primary Key Not Null,
+Create Table %PREFIX%CommitLog (Id Integer Auto_Increment Primary Key Not Null,
 	SessionId Integer,
 	Directory varchar(255),
 	Message text,
@@ -24,9 +24,9 @@ Create Table CommitLog (Id Integer Auto_Increment Primary Key Not Null,
 	Removed Integer,
 	Diff text);
 
-Create Index Commit_SessionId On CommitLog(SessionId);
+Create Index %PREFIX%Commit_SessionId On %PREFIX%CommitLog(SessionId);
 
-Create Table HistoryLog (Id Integer Auto_Increment Primary Key Not Null,
+Create Table %PREFIX%HistoryLog (Id Integer Auto_Increment Primary Key Not Null,
 	SessionId Integer,
 	Type char(1),
 	WorkDir varchar(255),
@@ -35,9 +35,9 @@ Create Table HistoryLog (Id Integer Auto_Increment Primary Key Not Null,
 	BugId varchar(64),
 	Message text);
 
-Create Index History_SessionId on HistoryLog(SessionId);
+Create Index %PREFIX%History_SessionId on %PREFIX%HistoryLog(SessionId);
 
-Create Table TagLog (Id Integer Auto_Increment Primary Key Not Null,
+Create Table %PREFIX%TagLog (Id Integer Auto_Increment Primary Key Not Null,
 	SessionId Integer,
 	Directory varchar(255),
 	Filename varchar(255),
@@ -47,4 +47,4 @@ Create Table TagLog (Id Integer Auto_Increment Primary Key Not Null,
 	Action varchar(32),
 	Type char(1));
 	
-Create Index Tag_SessionId on TagLog(SessionId);
+Create Index %PREFIX%Tag_SessionId on %PREFIX%TagLog(SessionId);
