@@ -1,6 +1,6 @@
 -- SQLite specific configuration script
 
-Create Table SessionLog (Id Integer Primary Key Not Null,
+Create Table %PREFIX%SessionLog (Id Integer Primary Key Not Null,
 	Command nvarchar(32),
 	Date datetime,
 	Hostname nvarchar(256),
@@ -10,7 +10,7 @@ Create Table SessionLog (Id Integer Primary Key Not Null,
 	PhysRepos nvarchar(256),
 	Client nvarchar(64));
 
-Create Table CommitLog (Id Integer Primary Key Not Null,
+Create Table %PREFIX%CommitLog (Id Integer Primary Key Not Null,
 	SessionId Integer,
 	Directory nvarchar(256),
 	Message text,
@@ -24,9 +24,9 @@ Create Table CommitLog (Id Integer Primary Key Not Null,
 	Removed Integer,
 	Diff text);
 
-Create Index Commit_SessionId On CommitLog(SessionId);
+Create Index %PREFIX%Commit_SessionId On %PREFIX%CommitLog(SessionId);
 
-Create Table HistoryLog (Id Integer Primary Key Not Null,
+Create Table %PREFIX%HistoryLog (Id Integer Primary Key Not Null,
 	SessionId Integer,
 	Type char(1),
 	WorkDir nvarchar(256),
@@ -35,9 +35,9 @@ Create Table HistoryLog (Id Integer Primary Key Not Null,
 	BugId nvarchar(64),
 	Message text);
 
-Create Index History_SessionId on HistoryLog(SessionId);
+Create Index %PREFIX%History_SessionId on %PREFIX%HistoryLog(SessionId);
 
-Create Table TagLog (Id Integer Primary Key Not Null,
+Create Table %PREFIX%TagLog (Id Integer Primary Key Not Null,
 	SessionId Integer,
 	Directory nvarchar(256),
 	Filename nvarchar(256),
@@ -47,4 +47,4 @@ Create Table TagLog (Id Integer Primary Key Not Null,
 	Action nvarchar(32),
 	Type char(1));
 	
-Create Index Tag_SessionId on TagLog(SessionId);
+Create Index %PREFIX%Tag_SessionId on TagLog(SessionId);
