@@ -55,10 +55,7 @@ extern "C" {
 /* Hah.  */
 #undef _MINIX
 
-// Apple or Howl mdns
-#define ENABLE_ZEROCONF
-#define HAVE_HOWL_H
-//#define HAVE_DNS_SD_H
+#include "../cvsapi/win32/config.h"
 
 /* Define to `int' if <sys/types.h> doesn't define.  */
 #define mode_t int
@@ -98,11 +95,6 @@ extern "C" {
    for HAVE_SYS_TIME_H anywhere in config.h.in?  */
 #undef TIME_WITH_SYS_TIME
 
-/* Define to `int' if <sys/types.h> doesn't define.  */
-/* Defined to void* for WinNT to take a handle (from LogonUser etc.) */
-//#define uid_t void*
-typedef void* uid_t;
-
 /* Define if you have MIT Kerberos version 4 available.  */
 /* We don't.  Cygnus says they've ported it to Windows 3.1, but
    I don't know if that means that it works under Windows NT as
@@ -513,6 +505,8 @@ int wnt_fclose(FILE *file);
 int wnt_access(const char *path, int mode);
 int wnt_utime(const char *filename, struct utimbuf *uf);
 
+void preparse_filename(char *filename);
+
 #define fopen wnt_fopen
 #define fclose wnt_fclose
 #define CVS_OPEN wnt_open
