@@ -7,7 +7,6 @@
 #include "cvs.h"
 
 #define WIN32_LEAN_AND_MEAN
-#define _WIN32_WINNT 0x0500
 #include <windows.h>
 #include <lm.h>
 #include <lmcons.h>
@@ -67,7 +66,7 @@ int nt_s4u(LPCWSTR wszMachine, LPCWSTR wszUser, HANDLE *phToken);
 /* Try to work out if this is a GMT FS.  There is probably
    a way of doing this that works for all FS's, but this
    detects FAT at least */
-#define GMT_FS(_s) (!strstr(_s,"FAT"))
+#define GMT_FS(_s) (!_tcsstr(_s,_T("FAT")))
 
 #ifndef CVS95
 ITypeLib *myTypeLib;
@@ -185,15 +184,6 @@ static char g_defaultdomain[DNLEN+1];
 // IsDomainMember patch from John Anderson <panic@semiosix.com>
 int isDomainMember(char *szDomain);
 
-typedef BOOL (WINAPI *MINIDUMPWRITEDUMP)(
-    IN HANDLE hProcess,
-    IN DWORD ProcessId,
-    IN HANDLE hFile,
-    IN MINIDUMP_TYPE DumpType,
-    IN CONST PMINIDUMP_EXCEPTION_INFORMATION ExceptionParam, OPTIONAL
-    IN CONST PMINIDUMP_USER_STREAM_INFORMATION UserStreamParam, OPTIONAL
-    IN CONST PMINIDUMP_CALLBACK_INFORMATION CallbackParam OPTIONAL
-    );
 static LONG WINAPI MiniDumper(PEXCEPTION_POINTERS pExceptionInfo);
 
 #endif
@@ -1141,6 +1131,17 @@ void win32_perror(int quit, const char *prefix, ...)
 	LocalFree((HLOCAL)buf);
 }
 
+void preparse_filename(char *fn)
+{
+	if(strlen(fn)>12 && !strncmp(fn,"/cygdrive/",10) && fn[11]=='/')
+	{
+		fn[0]=fn[10];
+		fn[1]=':';
+		fn[2]='\\';
+		strcpy(fn+3,fn+12);
+	}
+}
+
 #undef fopen
 #undef open
 #undef fclose
@@ -1153,6 +1154,7 @@ FILE *wnt_fopen(const char *filename, const char *mode)
 	uc_name wm = mode;
 
 	validate_filename(filename);
+
 	f = _tfopen(fn,wm);
 	return f;
 
@@ -1912,7 +1914,7 @@ static int _statcore(HANDLE hFile, const char *filename, struct stat *buf)
 {
     BY_HANDLE_FILE_INFORMATION bhfi;
 	int isdev;
-	char szFs[32];
+	TCHAR szFs[32];
 	int is_gmt_fs = -1;
 	uc_name fn = filename;
 
@@ -1984,20 +1986,22 @@ static int _statcore(HANDLE hFile, const char *filename, struct stat *buf)
 		// We have to assume here that the repository doesn't span drives, so the
 		// current directory is correct.
 		*szFs='\0';
-		GetVolumeInformationA(NULL,NULL,0,NULL,NULL,NULL,szFs,32);
+		GetVolumeInformation(NULL,NULL,0,NULL,NULL,NULL,szFs,32);
 
 		is_gmt_fs = GMT_FS(szFs);
 	}
 	else
 	{
-		if(filename[1]!=':')
+		uc_name fn = filename;
+
+		if(fn[1]!=':')
 		{
-			if((filename[0]=='\\' || filename[0]=='/') && (filename[1]=='\\' || filename[1]=='/'))
+			if((fn[0]=='\\' || fn[0]=='/') && (fn[1]=='\\' || fn[1]=='/'))
 			{
 				// UNC pathname: Extract server and share and pass it to GVI
-				char szRootPath[MAX_PATH + 1] = "\\\\";
-				const char *p = &filename[2];
-				char *q = &szRootPath[2];
+				TCHAR szRootPath[MAX_PATH + 1] = _T("\\\\");
+				const TCHAR *p = &fn[2];
+				TCHAR *q = &szRootPath[2];
 				int n;
 				for (n = 0; n < 2; n++)
 				{
@@ -2019,23 +2023,23 @@ static int _statcore(HANDLE hFile, const char *filename, struct stat *buf)
 				*q = 0;
 
 				*szFs='\0';
-				GetVolumeInformationA(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
+				GetVolumeInformation(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
 				is_gmt_fs = GMT_FS(szFs);
 			}
 			else
 			{
 				// Relative path, treat as local
-				GetVolumeInformationA(NULL,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
+				GetVolumeInformation(NULL,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
 				is_gmt_fs = GMT_FS(szFs);
 			}
 		}
 		else
 		{
 			// Drive specified...
-			char szRootPath[4] = "?:\\";
-			szRootPath[0]=filename[0];
+			TCHAR szRootPath[4] = _T("?:\\");
+			szRootPath[0]=fn[0];
 			*szFs='\0';
-			GetVolumeInformationA(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
+			GetVolumeInformation(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
 			is_gmt_fs = GMT_FS(szFs);
 		}
 	}
@@ -2268,21 +2272,21 @@ int wnt_chmod (const char *name, mode_t mode)
 
 int wnt_utime(const char *filename, struct utimbuf *uf)
 {
-	uc_name f = filename;
+	uc_name fn = filename;
 	HANDLE h;
 	int is_gmt_fs;
-	char szFs[32];
+	TCHAR szFs[32];
 	FILETIME At,Wt;
 
 	validate_filename(filename);
-	if(filename[1]!=':')
+	if(fn[1]!=':')
 	{
-		if((filename[0]=='\\' || filename[0]=='/') && (filename[1]=='\\' || filename[1]=='/'))
+		if((fn[0]=='\\' || fn[0]=='/') && (fn[1]=='\\' || fn[1]=='/'))
 		{
 			// UNC pathname: Extract server and share and pass it to GVI
-			char szRootPath[MAX_PATH + 1] = "\\\\";
-			const char *p = &filename[2];
-			char *q = &szRootPath[2];
+			TCHAR szRootPath[MAX_PATH + 1] = _T("\\\\");
+			const TCHAR *p = &fn[2];
+			TCHAR *q = &szRootPath[2];
 			int n;
 			for (n = 0; n < 2; n++)
 			{
@@ -2304,23 +2308,23 @@ int wnt_utime(const char *filename, struct utimbuf *uf)
 			*q = 0;
 
 			*szFs='\0';
-			GetVolumeInformationA(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
+			GetVolumeInformation(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
 			is_gmt_fs = GMT_FS(szFs);
 		}
 		else
 		{
 			// Relative path, treat as local
-			GetVolumeInformationA(NULL,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
+			GetVolumeInformation(NULL,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
 			is_gmt_fs = GMT_FS(szFs);
 		}
 	}
 	else
 	{
 		// Drive specified...
-		char szRootPath[4] = "?:\\";
-		szRootPath[0]=filename[0];
+		TCHAR szRootPath[4] = _T("?:\\");
+		szRootPath[0]=fn[0];
 		*szFs='\0';
-		GetVolumeInformationA(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
+		GetVolumeInformation(szRootPath,NULL,0,NULL,NULL,NULL,szFs,sizeof(szFs));
 		is_gmt_fs = GMT_FS(szFs);
 	}
 
@@ -2339,7 +2343,7 @@ int wnt_utime(const char *filename, struct utimbuf *uf)
 		LocalFileTimeToFileTime  ( &fAt, &At );
 		LocalFileTimeToFileTime  ( &fWt, &Wt );
 	}
-	h = CreateFile(f,FILE_WRITE_ATTRIBUTES,FILE_SHARE_READ|FILE_SHARE_WRITE,NULL,OPEN_EXISTING,0,NULL);
+	h = CreateFile(fn,FILE_WRITE_ATTRIBUTES,FILE_SHARE_READ|FILE_SHARE_WRITE,NULL,OPEN_EXISTING,0,NULL);
 	if(h==INVALID_HANDLE_VALUE)
 	{
 		DWORD dwErr = GetLastError();
